@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: compute.tcl
-#  Last change:  31 May 2004
+#  Last change:  21 October 2004
 #
 # Includes contributions by
 #  - Matt Martin (matt.martin@ieee.org) marked "MGM contribution"
@@ -72,9 +72,21 @@ proc Coord {pformt coord negh} {
     }
 }
 
-proc CreatePos {latd longd pformt datum} {
-    # create position representation under format $pformt
-    #  from lat/long in degrees, and $datum
+proc FormatPosition {latd longd datum reqpfmt pfdatum args} {
+    # produce formatted position from $latd and $longd in decimal
+    #  degrees for $datum
+    #  $reqpfmt is the required position format
+    #  $pfdatum is the datum to use with this format
+    #     if $pfdatum=="", $datum is used unless $reqpfmt needs a fixed datum
+    #     otherwise $pfdatum must be compatible with $reqpfmt; if it is
+    #     not a call to BUG will be made
+    #  $args is either "" or is an alternative format to be used with $datum
+    #     when conversion to $reqpfmt fails (out of grid scope)
+    # result is a list with: position representation, position format
+    #  used and datum used
+    # if $args=="" and conversion to $reqpfmt yields an out of grid scope
+    #  result ("--" in the zone or x-field), this result is used in
+    #  building the position representation
     # a position representation is a list whose first two elements
     #  are lat and long in degrees, and whose rest is dependent on format
     #  type:
@@ -85,42 +97,65 @@ proc CreatePos {latd longd pformt datum} {
     #       ==mh: Maidenhead-locator (6 characters)
     global POSTYPE
 
-    switch $POSTYPE($pformt) {
-	latlong {
-	    if { $latd < 0 } {
-		set la [expr -$latd] ; set hlat S
-	    } else {
-		set la $latd ; set hlat N
-	    }
-	    if { $longd < 0 } {
-		set lo [expr -$longd] ; set hlng W
-	    } else {
-		set lo $longd ; set hlng E
-	    }
-	    if { $pformt == "GRA" } {
-		set la [format %.5f [expr $latd/0.9]]
-		set lo [format %.5f [expr $longd/0.9]]
-		return [list $latd $longd $la $lo]
-	    }
-	    return [list $latd $longd "$hlat[ExtDegrees $pformt $la]" \
-		         "$hlng[ExtDegrees $pformt $lo]"]
-	}
-	utm {
-	    set p [DegreesToUTM $latd $longd $datum]
-	    return [linsert $p 0 $latd $longd]
-	}
-	grid {
-	    set p [DegreesTo$pformt $latd $longd $datum]
-	    return [linsert $p 0 $latd $longd]
-	}
-	nzgrid {
-	    set p [DegreesToNZGrid $pformt $latd $longd $datum]
-	    return [linsert $p 0 $latd $longd]
-	}
-	mh {
-	    return [list $latd $longd [DegreesToMHLoc $latd $longd]]
+    set la $latd ; set lo $longd
+    if { $pfdatum == "" } {
+	set udatum $datum
+    } else {
+	set udatum $pfdatum
+	if { $pfdatum != $datum } {
+	    foreach "la lo" [ToDatum $la $lo $datum $pfdatum] {	break }
 	}
     }
+    switch [set ptype $POSTYPE($reqpfmt)] {
+	latlong {
+	    set p [FormatLatLong $la $lo $reqpfmt]
+	}
+	utm {
+	    set p [linsert [DegreesToUTM $la $lo $udatum] 0 $la $lo]
+	}
+	grid -  nzgrid {
+	    if { [set gd [GridDatum $reqpfmt $udatum]] != $udatum } {
+		if { $pfdatum != "" } {
+		    BUG calling FormatPosition with wrong pfdatum
+		}
+		set udatum $gd
+		foreach "la lo" [ToDatum $latd $longd $datum $gd] { break }
+	    }
+	    if { $ptype == "grid" } {
+		set p [DegreesTo$reqpfmt $la $lo $udatum]
+	    } else { set p [DegreesToNZGrid $reqpfmt $la $lo $udatum] }
+	    if { [lindex $p 0] == "--" && $args != "" } {
+		# out of scope
+		return [FormatPosition $latd $longd $datum $args ""]
+	    }
+	    set p [linsert $p 0 $la $lo]
+	}
+	mh {
+	    set p [list $la $lo [DegreesToMHLoc $la $lo]]
+	}
+    }
+    return [list $p $reqpfmt $udatum]
+}
+
+proc FormatLatLong {latd longd pfmt} {
+    # produce formatted position from $latd and $longd in decimal
+    #  degrees in latitude/longitude position format
+    # result is the position representation: a list whose first two elements
+    #  are lat and long in degrees, followed by lat and long in external format
+
+    if { $latd < 0 } {
+	set lax [expr -$latd] ; set hlat S
+    } else { set lax $latd ; set hlat N }
+    if { $longd < 0 } {
+	set lox [expr -$longd] ; set hlng W
+    } else { set lox $longd ; set hlng E }
+    if { $pfmt == "GRA" } {
+	set lax [format %.5f [expr $latd/0.9]]
+	set lox [format %.5f [expr $longd/0.9]]
+	return [list $latd $longd $lax $lox]
+    }
+    return [list $latd $longd "$hlat[ExtDegrees $pfmt $lax]" \
+		"$hlng[ExtDegrees $pfmt $lox]"]
 }
 
 proc ExtDegrees {pformt degs} {
@@ -174,6 +209,7 @@ proc ChangeCoordSign {pos} {
 proc ConvertPos {pfrmt zone x y datum npfrmt} {
     # create position representation in format $npfrmt from position
     #  $x, $y (as decimal numbers) in format $pfrmt
+    #         if $pfrmt in {DDD, GRA} take $x as long and $y as lat
     #  $zone is either a list with ze and zn for UTM/UPS, or the zone
     #    name for other grids (and is meaningless for other formats
     # values of $x, $y are checked, as well as suitability of $datum
@@ -184,27 +220,28 @@ proc ConvertPos {pfrmt zone x y datum npfrmt} {
     switch [set ptype $POSTYPE($pfrmt)] {
 	latlong {
 	    # must be either DDD or GRA
-	    if { $x < 0 } {
-		set la [expr -$x] ; set hlat S
-	    } else {
-		set la $x ; set hlat N
+	    if { $pfrmt == "GRA" } {
+		set x [expr $x*0.9] ; set y [expr $y*0.9]
 	    }
 	    if { $y < 0 } {
-		set lo [expr -$y] ; set hlng W
+		set la [expr -$y] ; set hlat S
 	    } else {
-		set lo $y ; set hlng E
+		set la $y ; set hlat N
+	    }
+	    if { $x < 0 } {
+		set lo [expr -$x] ; set hlng W
+	    } else {
+		set lo $x ; set hlng E
 	    }
 	    if { ! [CheckCoord GMMessage $pfrmt $la N 90] || \
 		    ! [CheckCoord GMMessage $pfrmt $lo E 180] } {
 		return -1
 	    }
-	    if { $pfrmt == "GRA" } {
-		set x [expr $x*0.9] ; set y [expr $y*0.9]
-	    }
-	    if { $npfrmt == $pfrmt } {
+	    if { $npfrmt == "DDD" } {
 		return [list $y $x "${hlat}[format "%.5f" $la]" \
 			           "${hlng}[format "%.5f" $lo]"]
 	    }
+	    set la $y ; set lo $x
 	}
 	utm {
 	    foreach "ze zn" $zone {}
@@ -214,16 +251,11 @@ proc ConvertPos {pfrmt zone x y datum npfrmt} {
 	    }
 	}
 	grid -  nzgrid {
-	    set p [GridToDegrees $pfrmt $zone $x $y $datum]
-	    set la [lindex $p 0]
-	    if { [set lo [lindex $p 1]] == "" } {
-		if { $la == 0 } {
-		    set m $MESS(outofgrid)
-		} else {
-		    set m [format $MESS(badgriddatum) $TXT($pfrmt) \
-			          [GridDatum $pfrmt]]
-		}
-		GMMessage $m
+	    if { [BadDatumFor $pfrmt $datum GMMessage] != 0 } {
+		return -1
+	    }
+	    if { [set p [GridToDegrees $pfrmt $zone $x $y $datum]] == 0 } {
+		GMMessage $MESS(outofgrid)
 		return -1
 	    }
 	    if { $npfrmt == $pfrmt } {
@@ -236,7 +268,9 @@ proc ConvertPos {pfrmt zone x y datum npfrmt} {
 	    BUG calling ConvertPos with wrong format
 	}
     }
-    if { [lindex [set p [CreatePos $la $lo $npfrmt $datum]] 2] == "--" } {
+    # $datum is suitable for $npfrmt
+    set p [lindex [FormatPosition $la $lo $datum $npfrmt $datum] 0]
+    if { [lindex $p 2] == "--" } {
 	GMMessage $MESS(outofgrid)
 	return -1
     }
@@ -428,7 +462,7 @@ proc CompDistBearDatums {p1 d1 p2 d2} {
     # distance (km) between and bearing from positions $p1 and $p2
     #  with datums $d1 and $d2
     if { $d1 != $d2 } {
-	set p2 [ConvertDatum [lindex $p2 0] [lindex $p2 1] $d2 $d1 DDD]
+	set p2 [ToDatum [lindex $p2 0] [lindex $p2 1] $d2 $d1]
     }
     return [ComputeDistBear $p1 $p2 $d1]
 }
@@ -513,7 +547,7 @@ proc ProjectedArea {wpixs} {
     foreach ix [lreplace $wpixs 0 0] {
 	set dt $WPDatum($ix) ; set p $WPPosn($ix)
 	if { $dt != $datum } {
-	    set p [ConvertDatum [lindex $p 0] [lindex $p 1] $dt $datum DDD]
+	    set p [ToDatum [lindex $p 0] [lindex $p 1] $dt $datum]
 	}
 	lappend ps [list [lindex $p 0] [lindex $p 1] $datum]
     }
@@ -576,8 +610,8 @@ proc SphericalArea {wpixs} {
     foreach ixn [lreplace $wpixs 0 0] {
 	set pos $WPPosn($ixn)
 	if { $WPDatum($ixn) != $datum } {
-	    set pos [ConvertDatum [lindex $pos 0] [lindex $pos 1] \
-		    $WPDatum($ixn) $datum DDD]
+	    set pos [ToDatum [lindex $pos 0] [lindex $pos 1] \
+		    $WPDatum($ixn) $datum]
 	}
 	set phi1 [expr [lindex $pos 0]*0.01745329251994329576]
 	set lam1 [expr [lindex $pos 1]*0.01745329251994329576]
@@ -628,8 +662,8 @@ proc ChangeTPsDatum {tps datum1 datum2} {
     if { $datum1 == $datum2 } { return $tps }
     set l ""
     foreach tp $tps {
-	set np [ConvertDatum [lindex $tp 0] [lindex $tp 1] \
-		             $datum1 $datum2 DMS]
+	set np [lindex [FormatPosition [lindex $tp 0] [lindex $tp 1] \
+			    $datum1 DMS $datum2] 0]
 	lappend l [concat $np [lrange $tp 4 end]]
     }
     return $l
@@ -641,12 +675,11 @@ proc ChangeLPsDatum {lps odatum datum pformt} {
     # this depends on DataIndex (see main.tcl, Storage), not used here
     #  for speed
     # return -1 if the current position format requires a fixed datum
+    #  different from $datum
     global MESS POSTYPE
 
     if { $odatum == $datum } { return $lps }
-    if { ([set pt $POSTYPE($pformt)] == "grid" || $pt == "nzgrid") && \
-	    [set gdatum [GridDatum $pformt]] != "" && \
-	    $datum != $gdatum } {
+    if { [set gd [BadDatumFor $pformt $datum Ignore]] != 0 } {
 	GMMessage [format $MESS(cantchggriddatum) $gdatum]
 	return -1
     }
@@ -654,7 +687,8 @@ proc ChangeLPsDatum {lps odatum datum pformt} {
     foreach lp $lps {
 	foreach "latd longd" [lindex $lp 0] { break }
 	lappend l [lreplace $lp 0 0 \
-		            [ConvertDatum $latd $longd $odatum $datum $pformt]]
+		       [lindex [FormatPosition $latd $longd $odatum \
+				    $pformt $datum] 0]]
     }
     return $l
 }
@@ -692,6 +726,15 @@ proc Today {dformt} {
     return [FormatDate $dformt $y $m $d $h $mn $s]
 }
 
+proc TodayUTC {dformt} {
+    # VR contribution
+    # build representation of current date under format $dformt
+
+    set dt [clock format [clock seconds] -format "%Y %m %d %H %M %S"]
+    scan $dt %d%0d%0d%0d%0d%0d y m d h mn s
+    return [eval FormatDate $dformt [LocalTimeAndUTC $y $m $d $h $mn $s Local]]
+}
+
 proc FormatDay {dformt y m d} {
     # build representation of date (without time of day) under format $dformt
     # (see proc FormatDate for date with time of day)
@@ -716,6 +759,10 @@ proc FormatDate {dformt y m d h mn s} {
     # when adding new formats here, array DATEW must be updated in main.tcl
     global MONTHNAMES
 
+    # make sure there are no leading 0's
+    foreach v "y m d h mn s" {
+	scan [set $v] %0d $v
+    }
     set h [format "%02d:%02d:%02d" $h $mn $s]
     switch $dformt {
 	DDMMYY {
@@ -737,14 +784,47 @@ proc FormatDate {dformt y m d h mn s} {
     }
 }
 
-proc FormatTime {secs} {
+proc FormatTime {secs args} {
     # build represention of seconds in hours:minutes:seconds format
+    #  $secs may be a float or an integer
+    # if $args!="" it gives the number of decimal places for the seconds field
+    #  that defaults to 0 with $secs rounded to integer
 
-    set s [expr $secs%60] ; set x [expr ($secs-$s)/60]
+    if { $args != "" && $args > 0 } {
+	set fss "%02.${args}f" ; set fss0 "%8.${args}f"
+    } else {
+	set secs [expr round($secs)]
+	set fss "%02d" ; set fss0 "%8d"
+    }
+    set s0 [expr int($secs)]
+    set s [expr $s0%60] ; set x [expr ($s0-$s)/60]
+    set s [expr $s+$secs-$s0]
     set mn [expr $x%60] ; set h [expr ($x-$mn)/60]
-    if { $h > 0 } { return [format "%2d:%02d:%02d" $h $mn $s] }
-    if { $mn > 0 } { return [format "%5d:%02d" $mn $s] }
-    return [format "%8d" $s]
+    if { $h > 0 } { return [format "%2d:%02d:$fss" $h $mn $s] }
+    if { $mn > 0 } { return [format "%5d:$fss" $mn $s] }
+    return [format $fss0 $s]
+}
+
+proc TimeToSecs {time} {
+    # convert represention of seconds in hours:minutes:seconds format
+    #  to seconds (hours and minutes fields may be missing)
+    # return integer or float according to seconds field
+
+    set n [llength [set l [split $time ":"]]]
+    set s [lindex $l end]
+    if { [string first 0 $s] == 0 } { set s [string range $s 1 end] }
+    if { $n == 1 } { return $s }
+    set ll ""
+    foreach f $l {
+	scan $f %0d f
+	lappend ll $f
+    }
+    scan [lindex $l 0] %0d f
+    if { $n == 2 } {
+	return [expr $s+60*$f]
+    }
+    scan [lindex $l 1] %0d g
+    return [expr $s+60*$g+3600*$f]
 }
 
 proc NowTZ {} {
@@ -767,8 +847,9 @@ array set DAYSOF {
 }
 
 proc ScanDate {date} {
-    # convert GPSMan date to a list with year, month (in 1..12), day,
+    # convert date string to a list with year, month (in 1..12), day,
     #  hours, minutes and seconds
+    # if there is time zone information, return local time
     # return empty list on error
     # see proc FormatDate for possible date formats
     # changes in proc FormatDate are likely to affect this proc!
@@ -787,18 +868,36 @@ proc ScanDate {date} {
 	return [list $y $m $d 0 0 0]
     }
     set goodn -1
-    if { [regexp {^ *([-0-9]+)T([0-9:]+)Z *$} $date m ymd hms] } {
-	# coping with ISO8601 format : 2000-01-01T12:00:00Z
-	# based on VR contribution
+    if { [regexp {^ *([-0-9]+)T([0-9:.]+)([^ ]+) *$} $date m ymd hms tail] } {
+	# coping with ISO8601 format as in:
+	#   2000-01-01T12:00:00Z
+	#   2000-01-01T12:00:00.00000Z
+	#   2004-06-07T13:51:27.2515650-07:00
 	set n 1
-	if { [llength [set ymd [split $ymd -]]] == 3 && \
-		 [llength [set hms [split $hms :]]] == 3 } {
-	    set goodn 6
-	    foreach "y m d" $ymd {}
-	    foreach "h mn s" $hms {}
-	    foreach v "m d h mn s" {
-		incr n [scan [set $v] "%0d" $v]
-	    }
+	if { [scan $hms %02d:%02d:%0f h mn s] == 3 && \
+		 [scan $ymd %4d-%02d-%02d y m d] == 3 } {
+	    set s [expr round($s)]
+	    if { [scan $tail %03d:%02d hz mz] == 2 } {
+		set goodn 1
+		# compute UTC date
+		if { $hz > 0 } { set mz [expr -$mz] }
+		set hz [expr -$hz]
+		if { [incr mn $mz] > 60 } {
+		    incr h ; set mn [expr $mn-60]
+		} elseif { $mn < 0 } {
+		    incr h -1 ; incr mn 60
+		}
+		if { [incr h $hz] > 23 } {
+		    incr h -24
+		    foreach "y m d" [NextDay $y $m $d] {}
+		} elseif { $h < 0 } {
+		    incr h 24
+		    foreach "y m d" [PreviousDay $y $m $d] {}
+		}
+		# convert to local date
+		foreach "y m d h mn s" \
+		    [LocalTimeAndUTC $y $m $d $h $mn $s UTC] {}
+	    } elseif { $tail == "Z" } { set goodn 1 }
 	}
     } else {
 	set l [split $date -] ; set n [llength $l]
@@ -861,6 +960,10 @@ proc DateToSecsFrom {y m d h mn s year0} {
     #  necessarily a leap year
     global DAYSOF
 
+    # make sure there are no leading 0's
+    foreach v "y m d h mn s" {
+	scan [set $v] %0d $v
+    }
     # days in current month and in whole years except February 29ths
     set days [expr 365*($y-$year0)+$d-1]
     set yy [expr $year0+$year0%4]
@@ -964,6 +1067,24 @@ proc NextDay {y m d} {
     return [list $y $m $d]
 }
 
+proc PreviousDay {y m d} {
+    # return list with year, month and day for the day before the
+    #  given date
+    global DAYSOF
+
+    if { [incr d -1] == 0 } {
+	if { [incr m -1] == 0 } {
+	    set m 12 ; incr y -1
+	}
+	if { $m==2 && $y%4==0 && ($y%100!=0 || $y%400==0) } {
+	    set d 29
+	} else {
+	    set d $DAYSOF($m)
+	}
+    }
+    return [list $y $m $d]
+}
+
 proc Month {name} {
     # from month name to 0 (error) or 1..12
     global ALLMONTH
@@ -998,7 +1119,7 @@ proc LocalTimeAndUTC {y m d h mn s origin} {
 		}
 	    }
 	}
-    } elseif { $h > 24 } {
+    } elseif { $h > 23 } {
 	incr h -24
 	if { [incr d] > $DAYSOF($m) } {
 	    if { $m == 2 } {
@@ -1022,6 +1143,9 @@ proc CompatibleDates {y0 m0 d0 secs1} {
     #  $secs1 is the other date in seconds since $YEAR0
     # return 1 if compatible
 
+    if { $m0 != "*" && [set m0 [Month $m0]] == 0 } {
+	BUG calling CompatibleDates with bad month name
+    }
     foreach "y1 m1 d1 h1 mn1 s1" [DateIntsFromSecs $secs1] {}
     if { [string match $d0-$m0-$y0 $d1-$m1-$y1] } { return 1 }
     return 0
@@ -1041,3 +1165,4 @@ proc VectorBearing {vx vy} {
     return $b
 }
 
+
