@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: elevation.tcl
-#  Last change:  3 June 2004
+#  Last change:  7 September 2004
 #
 # This file contains mostly code contributed by Alessandro Palmas
 #   (alpalmas@tin.it)
@@ -325,8 +325,11 @@ proc Hgraph {k what args} {
 	    set tmp [Hnormalize $y $ymin $scaly]
 	    set tmp [expr $MY-$tmp]
 	    set tmp [expr int($tmp)]
-	    $c create line 0 $tmp $MX $tmp -fill "tan" -width 2
-	    $c create text 50 $tmp -fill "red" -text "$y"
+	    # MF contribution: lowering these items
+	    set it [$c create text 50 $tmp -fill "red" -text "$y"]
+	    $c lower $it
+	    set it [$c create line 0 $tmp $MX $tmp -fill "tan" -width 2]
+	    $c lower $it
 	}
     }
     # for plot data is beautified
@@ -348,7 +351,10 @@ proc Hgraph {k what args} {
 	    if {($x<$xmax)&&($x>$xmin)} {
 		set tmp [Hnormalize ($x $xmin $scalx)]
 		set tmp [expr int($tmp)]
-		$c create line $tmp $MY $tmp [expr $MY - 10] -fill "tan" 
+		# MF contribution: lowering these items
+		set it \
+		    [$c create line $tmp $MY $tmp [expr $MY - 10] -fill "tan"]
+		$c lower $it
 	    }
 	}
     } else {
@@ -392,20 +398,24 @@ proc Hgraph {k what args} {
 		} else { incr hour0 }
 	    } else { incr min0 $min_d }
 	    set tmp [expr [Hnormalize $x 0 $scalx]]
-	    $c create line $tmp $MY $tmp [expr $MY - 10] -fill "tan"
-	    $c create text $tmp $MY -anchor n \
-		-text [format "%02d:%02d" $hour0 $min0] -fill red
+	    set it [$c create text $tmp $MY -anchor n \
+			-text [format "%02d:%02d" $hour0 $min0] -fill red]
+	    $c lower $it
+	    set it [$c create line $tmp $MY $tmp [expr $MY - 10] -fill "tan"]
+	    $c lower $it
 	    if { [incr x $deltax] > $xmax } { break }
 	}
     }
     # MF change: time values are self-documented, placing extreme values
-    #   replaced "h. max"/"h. min" by "max"/"min"
+    #   replaced "h. max"/"h. min" by "max"/"min"; lowering the items
     set xextrs 50
     if { $totdist } {
-	$c create text [expr $MX - 60] [expr $MY + 15] -fill "black" \
-	    -text "delta $deltax"
-	$c create text [expr $MX - 50] [expr $MY + 5] -fill "black" \
-	    -text "tot. $xexcursion"
+	set it [$c create text [expr $MX - 60] [expr $MY + 15] -fill "black" \
+		    -text "delta $deltax"]
+	$c lower $it
+	set it [$c create text [expr $MX - 50] [expr $MY + 5] -fill "black" \
+		    -text "tot. $xexcursion"]
+	$c lower $it
     } else {
 	set xhr0 [Hnormalize $xhr0 0 $scalx]
 	set deltax [Hnormalize $deltax 0 $scalx]
@@ -1175,7 +1185,9 @@ proc HG3D_canvas {alt} {
 	set s2k [button $f0b.srk -text $TXT(show) \
 		-command { HG3D_do_calc pow } -state disabled]
 	set HG3Dglob(shbutton) $s2k
+        # MF contribution: using variable so that status is correctly displayed
 	set s2r [checkbutton $f0a.sr2 -text $TXT(animate) \
+		-variable HG3Dglob(anim_en) \
 		-command "HG3D_animtog $w $s2" -selectcolor $COLOUR(check)]
 	#--
 	# MF contribution
