@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: files.tcl
-#  Last change:  17 May 2004
+#  Last change:  22 October 2004
 #
 # See also files_foreign.tcl
 #  and gpsman.tcl for properties of known file formats
@@ -30,8 +30,9 @@
 
 array set FCOMMAND {
     format  "!Format:"
-    pformat "!Position:"
     datum   "!Datum:"
+    pformat "!Position:"
+    pfdatum "!PFDatum:"
     dates   "!Creation:"
     0   no
     1   yes
@@ -42,11 +43,13 @@ array set FCOMMAND {
     TS   "!TS:"
     LN   "!LN:"
     LS   "!LS:"
+    LAP  "!LAP:"
     GR   "!G:"
     GRWP   "!GW:"
     GRRT   "!GR:"
     GRTR   "!GT:"
     GRLN   "!GL:"
+    GRLAP  "!GLAP:"
     GRGR   "!GG:"
     nb   "!NB:"
     comment   "%"
@@ -60,9 +63,9 @@ array set FCOMMAND {
     mapinfo    "!Map:"
 }
 
-set FCOMMARGS {RT RS TR LN GR GRWP GRRT GRTR GRLN GRGR nb format pformat
-               datum dates mapback mapproj maptransf maporigin mapscale
-               mapbackat mapbackcs}
+set FCOMMARGS {RT RS TR LN LAP GR GRWP GRRT GRTR GRLN GRLAP GRGR nb format
+               pformat pfdatum datum dates mapback mapproj maptransf
+               maporigin mapscale mapbackat mapbackcs}
 
   # attribute-value pairs:
   #    name of attribute, data array name, var for default value, and proc
@@ -78,6 +81,7 @@ array set FATTRPAIRS {
         {colour TRColour DEFTTRCOLOUR BadColour}}
     LN {{width LNWidth DEFTLNWIDTH BadWidth}
         {colour LNColour DEFTLNCOLOUR BadColour}}
+    LAP {}
 }
 
 # needing a global variable (not array) for default colours
@@ -364,11 +368,37 @@ proc SaveLN {file ixs} {
     return
 }
 
+proc SaveLAP {file ixs} {
+    # save data for LAPs with indices in list $ixs to file in GPSMan format
+    global FCOMMAND LAPName LAPObs LAPDur LAPDist LAPBegPosn LAPEndPosn \
+	LAPCals LAPTRIx LAPPFrmt LAPDatum SFileDatum SFilePFrmt
+
+    WriteHeader $file $LAPPFrmt([lindex $ixs 0])
+    foreach i $ixs {
+	if { [SlowOpAborted] } { return }
+	if { $LAPDatum($i) != $SFileDatum($file) } {
+	    WriteChgDatum $file $LAPDatum($i)
+	}
+	if { $LAPPFrmt($i) != $SFilePFrmt($file) } {
+	    WriteChgPFormat $file $LAPPFrmt($i)
+	}
+	puts -nonewline $file [format "%s\t%s\t" $FCOMMAND(LAP) $LAPName($i)]
+	puts -nonewline $file "$LAPDur($i)\t$LAPDist($i)\t"
+	puts -nonewline $file "[lrange $LAPBegPosn($i) 2 end]\t"
+	puts -nonewline $file "[lrange $LAPEndPosn($i) 2 end]\t"
+	puts $file "$LAPCals($i)\t$LAPTRIx($i)"
+	SaveNB $file $LAPObs($i)
+    }
+    return
+}
+
 proc SaveGR {file ixs} {
     # save data for GRs with indices in list $ixs to file in GPSMan format
-    global SFileHeader TYPES FCOMMAND MESS GRName GRObs GRConts
+    global SFileHeader TYPES SUPPORTLAPS FCOMMAND MESS GRName GRObs GRConts
 
-    foreach wh $TYPES {
+    set gtypes $TYPES
+    if { $SUPPORTLAPS } { lappend gtypes LAP }
+    foreach wh $gtypes {
 	set l [GRsElements $ixs 1 $wh]
 	if { $wh != "GR" } {
 	    if { $l != "" } {
@@ -536,7 +566,7 @@ proc SaveMapBkInfo {file args} {
 proc SaveMapInfo {file args} {
     # save map datum, projection, transformation, grid and scale
     #  $args is list with projection data, transformation data, position
-    #    format of coordinates, and scale
+    #    format of coordinates, datum for coordinates and scale
     # projection and transformation data are lists with a name and a sequence
     #  of attribute=value pairs
     global Datum FCOMMAND MESS
@@ -560,29 +590,33 @@ proc SaveMapInfo {file args} {
     }
     puts $file ""
     puts $file "$FCOMMAND(pformat) [lindex $args 2]"
-    puts $file "$FCOMMAND(mapscale) [lindex $args 3]"
+    puts $file "$FCOMMAND(pfdatum) [lindex $args 3]"
+    puts $file "$FCOMMAND(mapscale) [lindex $args 4]"
     puts $file ""
     return
 }
 
 proc SaveGREls {how args} {
     # save elements of group to file in GPSMan format
+    # if file != "stdout" file will be closed at the end
     #  $how==all: all elements in all groups
     #  $how==select: groups and element types chosen from list
     #  $args not used but in call-back
-    global GRName SFilePFrmt SFileDatum SFileHeader TYPES MESS TXT
+    global GRName SFilePFrmt SFileDatum SFileHeader TYPES SUPPORTLAPS MESS TXT
 
+    set gtypes $TYPES
+    if { $SUPPORTLAPS } { lappend gtypes LAP }
     switch $how {
 	all {
 	    set ixs [array names GRName]
-	    set whs $TYPES
+	    set whs $gtypes
 	}
 	select {
 	    if { [set ixs [ChooseItems GR]] == "" } { return }
 	    set ts ""
-	    foreach k $TYPES { lappend ts $TXT(name$k) }
+	    foreach k $gtypes { lappend ts $TXT(name$k) }
 	    if { [set whs \
-		    [GMChooseFrom many $MESS(putwhat) 6 $ts $TYPES]] == "" } {
+		    [GMChooseFrom many $MESS(putwhat) 6 $ts $gtypes]] == "" } {
 	       return
 	   }
 	}
@@ -604,7 +638,7 @@ proc SaveGREls {how args} {
 	    unset SFilePFrmt($f) ; unset SFileDatum($f)
 	    unset SFileHeader($f)
 	}
-	close $f
+	if { $f != "stdout" } { close $f }
 	SlowOpFinish ""
     }
     return
@@ -617,10 +651,10 @@ proc SaveFile {how what args} {
     #            $args: normally the window containing the information; see
     #              procs Save$what
     #  $how==all: all items of type $what
-    #            $what in $TYPES or $what==Data
+    #            $what in $TYPES or $what=="LAP" or $what=="Data"
     #  $how==state: as "all" but without slow operation dialog
     #  $how==select: items of type $what chosen from list
-    #            $what in $TYPES
+    #            $what in $TYPES or $what=="LAP"
     #  $how==mapback: map background image information
     #            (used when saving state: no slow operation dialog)
     #            $what: MapBkInfo
@@ -637,15 +671,18 @@ proc SaveFile {how what args} {
 proc SaveFileTo {f how what args} {
     # save information to file $f in GPSMan format
     # if $f=="" ask user to select output file
+    # if $f!="stdout" file will be closed at the end
     # see proc SaveFile for the description of the arguments
-    global SFilePFrmt SFileDatum SFileHeader TXT TYPES
+    global SFilePFrmt SFileDatum SFileHeader TXT TYPES SUPPORTLAPS
 
+    set stypes $TYPES
+    if { $SUPPORTLAPS } { lappend stypes LAP }
     if { $how == "state" } {
 	set slow 0
     } else { set slow 1 }
     switch $how {
 	all -  state {
-	    set lp [AllIndicesForType $what $TYPES]
+	    set lp [AllIndicesForType $what $stypes]
 	}
 	select {
 	    if { [set ixs [ChooseItems $what]] == "" } { return }
@@ -674,7 +711,7 @@ proc SaveFileTo {f how what args} {
 	    unset SFilePFrmt($f) ; unset SFileDatum($f)
 	    unset SFileHeader($f)
 	}
-	close $f
+	if { $f != "stdout" } { close $f }
 	if { $slow } {
 	    SlowOpFinish ""
 	} else { ResetCursor . }
@@ -688,8 +725,11 @@ proc SaveState {} {
     # save current state of interface and current data
     # slow operation dialog not used
     global USvState USvData USvMap MESS Number MapEmpty Map TYPES EdWindow \
-	    MapPFormat MapFont Travelling Travel GMEd
+	    MapPFormat MapPFDatum MapPFNeedsDatum MapFont Travelling Travel \
+	    GMEd SUPPORTLAPS
 
+    set stypes $TYPES
+    if { $SUPPORTLAPS } { lappend stypes LAP }
     set todispl "" ; set toopen ""
     if { $Number(Data) != 0 } {
 	if { [catch {set f [open $USvData w]}] } {
@@ -698,7 +738,7 @@ proc SaveState {} {
 	}
 	set saveddata $USvData
 	SaveFileTo $f state Data
-	foreach wh $TYPES {
+	foreach wh $stypes {
 	    global ${wh}Displ
 
 	    set ns "" ; set os ""
@@ -748,6 +788,8 @@ proc SaveState {} {
     if { $savedmap != "" } {
 	puts $f "set mapfile \"$mapfile\""
 	puts $f "set mappformat \"$MapPFormat\""
+	puts $f "set mappfdatum \"$MapPFDatum\""
+	puts $f "set mappfndatum \"$MapPFNeedsDatum\""
 	puts $f "set mapfont \"$MapFont\""
     }
     puts $f ""
@@ -772,7 +814,8 @@ proc SaveState {} {
 proc RestoreState {} {
     # restore saved state and clear it if the user agrees
     global USvState MESS CREATIONDATE Proc DELSTATE MapPFormat Map MapFont \
-	    Travelling Travel MapEmpty ASKPROJPARAMS
+	    Travelling Travel MapEmpty ASKPROJPARAMS Datum MapPFDatum \
+	    MapPFNeedsDatum
 
     if { [file size $USvState] == 0 } { return }
     source $USvState
@@ -789,18 +832,28 @@ proc RestoreState {} {
     } else { set del 0 }
     if { $savedmap != "" } {
 	if { $mapfile == "Back" } {
-	    set MapEmpty 0
 	    set r [LoadMapFixedBk $savedmap]
-	    if { [lindex $r 0] == 1 } {
-		eval LoadMapBackGeoRef [lrange $r 1 end]
-		set MapPFormat $mappformat
-	    } else { return }
+	    if { $r == -1 } { return }
+	    if { [lindex $r 0] != 1 } {
+		GMMessage "$MESS(badfile): $savedmap"
+		return
+	    }
+	    set MapEmpty 0
+	    eval LoadMapBackGeoRef [lrange $r 1 end]
 	} else {
 	    # $mapfile == "Params"
 	    set r [LoadMapInfo $savedmap]
 	    if { $r == -1 } { return }
 	    eval LoadMapParams $r
 	}
+	set MapPFormat $mappformat
+	# compatibility with 6.1.2 and older versions
+	if { [catch {set mappfdatum}] } {
+	    set MapPFDatum $Datum
+	    ChangeMapPFormat $MapPFormat
+	} else {
+	    set MapPFDatum $mappfdatum ; set MapPFNeedsDatum $mappfndatum
+	}
 	if { ! [catch {set mapfont}] } { set MapFont $mapfont }
 	if { $del } { file delete -- $savedmap }
     }
@@ -824,11 +877,14 @@ proc RestoreState {} {
     set ASKPROJPARAMS $a
     foreach p $toopen {
 	set wh [lindex $p 0]
-	set opts "change revert create forget cancel"
+	if { $wh == "LAP" } {
+	    set opts "change revert forget cancel"
+	} else { set opts "change revert create forget cancel" }
 	foreach n [lindex $p 1] {
-	    set ix [IndexNamed $wh $n]
-	    $Proc($wh) $ix $opts [ItemData $wh $ix]
-	    set opts ""
+	    if { [set ix [IndexNamed $wh $n]] != -1 } {
+		$Proc($wh) $ix $opts [ItemData $wh $ix]
+		set opts ""
+	    }
 	}
     }
     if { $del } { file delete -- $USvState }
@@ -923,7 +979,7 @@ proc SaveCanvas {cv bounds fmt dest} {
 	if { $GFScale } {
 	    # only applies when $cv == $Map
 	    set m $MAPSCLENGTH ; set m2 [expr $m/2.0]
-	    scan [$MpW.frm.frmap3.cv.val cget -text] "%f %s" sc su
+	    scan [$MpW.frm.frmap3.fr3.cv.val cget -text] "%f %s" sc su
 	    if { [set xs0 [expr $sm-$m2]] < $x0 } {
 		set m $m2
 		if { [set xs0 [expr $sm-$m/2.0]] < $x0 } {
@@ -1023,9 +1079,8 @@ proc SaveCanvas {cv bounds fmt dest} {
 
 proc OpenInputFileFails {what fmt} {
     # open file for loading/importing and set initial values
-    #  $what in $TYPES or $what==Data
-    #  $fmt in {GPSMan, GPStrans, EasyGPS, Fugawi, GD2, GPX, GTrackMaker,
-    #           MapGuide, MapSend, Meridian, NMEA, IGC}
+    #  $what in $TYPES or $what=="LAP" or $what=="Data"
+    #  $fmt is such that "in" is in $FILEFORMAT($fmt,mode)
     # return 0 unless operation is to be cancelled
     global CREATIONDATE GFVisible TXT MESS FILEFORMAT
 
@@ -1053,17 +1108,14 @@ proc OpenInputFileFails {what fmt} {
 	    set for loadfrm ; set cr $CREATIONDATE
 	}
 	GPStrans {
+	    # some code for loading GPSMan is used for importing GPStrans
 	    set for importfrm ; set cr 1
 	}
-	Fugawi -  GD2 -  GPX -  GTrackMaker -  EasyGPS -
-	MapSend -  Meridian -  NMEA -  IGC {
+	default {
 	    # incorporates MGM contribution
 	    # incorporates VR contribution
 	    set for importfrm ; set cr 0
 	}
-	MapGuide {
-	    set for importfrm ; set cr 0
-	}
     }
     # mapping items is always an option
     set GFVisible 0
@@ -1096,7 +1148,7 @@ proc OpenInputFileFails {what fmt} {
 	if { $ok } {
 	    break
 	}
-	GMMessage [format $MESS($ms) $p $val]
+	GMMessage [format $MESS($ms) $p $val] wait
 	set $var $dv
     }
     InitInputFileVars $f $what $cr $GFVisible
@@ -1105,7 +1157,7 @@ proc OpenInputFileFails {what fmt} {
 
 proc InitInputFileVars {f what cr vis} {
     # initialise input file $f global variables
-    #  $what in $TYPES or $what==Data
+    #  $what in $TYPES or $what=="LAP" or $what=="Data"
     #  $cr set if creation date is in use
     #  $vis set if must display items read in
     global LFileLNo LFileCreat LFileBuffFull LFileEOF LFileDefs LFileVisible \
@@ -1121,13 +1173,14 @@ proc InitInputFileVars {f what cr vis} {
 
 proc CloseInputFile {what} {
     # close file opened for loading/importing and unset some global variables
-    #  $what in $TYPES
+    # if file is "stdin" it will not be closed
+    #  $what in $TYPES or $what=="LAP"
     global LFilePFrmt LFileDatum LFileLNo LFileCreat \
 	    LFileId LFileOther LFileBuff LFileBuffFull LFileEOF LFileDefs \
 	    LFileVisible LChannel
 
     set f $LChannel($what)
-    close $f
+    if { $f != "stdin" } { close $f }
     foreach v "LFilePFrmt($f) LFileDatum($f) \
 	    LFileLNo($f) LFileCreat($f) LFileDefs($f) LFileId($f) \
 	    LFileOther($f) LFileBuff($f) LFileBuffFull($f) \
@@ -1328,14 +1381,14 @@ proc FindArgs {commd line file} {
 		return RS
 	    }
 	}
-	TR -  LN {
+	TR -  LN -  LAP {
 	    set l [split $line \t]
 	    set LFileId($file) [lindex $l 0]
-	    # attributes
+	    # attributes or other fields
 	    set LFileOther($file) [lreplace $l 0 0]
 	    return $commd
 	}
-	GR -  GRWP -  GRRT -  GRTR -  GRLN -
+	GR -  GRWP -  GRRT -  GRTR -  GRLN -  GRLAP -
 	GRGR {
 	    set LFileId($file) [lindex [split $line \t] 0]
 	    return $commd
@@ -1379,14 +1432,13 @@ proc FindArgs {commd line file} {
 		return pformat
 	    }
 	}
-	datum {
+	datum -  pfdatum {
 	    if { [DatumRefId $line] != -1 } {
 		set LFileDatum($file) $line
 		set LFileDefs($file) [expr $LFileDefs($file)|1]
-		return datum
-	    } else {
-		GMMessage "$MESS(unkndatum): $line"
+		return $commd
 	    }
+	    GMMessage "$MESS(unkndatum): $line"
 	}
 	mapback {
 	    if { $line != "" } {
@@ -1420,9 +1472,8 @@ proc FindArgs {commd line file} {
 	    if { [scan $line %d,%d%s x y p] == 3 } {
 		set LFileIxPath($file) [list $x $y $p]
 		return $commd
-	    } else {
-		GMMessage "$MESS(mbkbadat): $line"
 	    }
+	    GMMessage "$MESS(mbkbadat): $line"
 	}
     }
     return BADC
@@ -1553,14 +1604,13 @@ proc ReadPosn {fs i file} {
 		 ! [CheckNumber GMMessage $nng] } {
 	       return -1
 	    }
+	    if { [BadDatumFor $pformt $LFileDatum($file) GMMessage] != 0 } {
+		return -1
+	    }
 	    set pd [GridToDegrees $pformt $zone $eng $nng $LFileDatum($file)]
 	    if { $pd == 0 } {
 		GMMessage $MESS(outofgrid)
 		return -1
-	    } elseif { $pd == -1 } {
-		GMMessage [format $MESS(badgriddatum) $TXT($pformt) \
-			          [GridDatum $pformt]]
-		return -1
 	    }
 	    if { $gr } {
 		set PosnLength 3
@@ -1647,7 +1697,7 @@ proc LoadWPs {file outRT importing how} {
 	if { [set m [CleanLine $m $importing]] == "" } { continue }
 	if { ! $importing && [string first ! $m]==0 } {
 	    switch -glob [ProcCommand $m $file] {
-		WP -  RT -  TR -  LN -
+		WP -  RT -  TR -  LN -  LAP -
 		GR {
 		    set LFileBuffFull($file) 1
 		    return $wps
@@ -1882,7 +1932,7 @@ proc LoadTPs {file importing e0} {
 	if { ! $importing && [string first ! $line] == 0 } {
 	    switch [ProcCommand $line $file] {
 		format -  datum -  pformat -  dates - 
-		WP -  RT -  TR -  LN -
+		WP -  RT -  TR -  LN -  LAP -
 		GR {
 		    set LFileBuffFull($file) 1
 		    return [list $tps $segsts]
@@ -1941,8 +1991,7 @@ proc LoadTPs {file importing e0} {
 	set posn [ReadPosn $fs 2 $file]
 	if { $posn == -1 } { return "" }
 	if { $LFilePFrmt($file) != "DMS" } {
-	    set posn [CreatePos [lindex $posn 0] [lindex $posn 1] DMS \
-			  $LFileDatum($file)]
+	    set posn [FormatLatLong [lindex $posn 0] [lindex $posn 1] DMS]
 	}
 	set tp [FormData TP $ns [concat $posn $date $ad]]
 	lappend tps $tp
@@ -2013,7 +2062,7 @@ proc LoadLPs {file} {
 	if { [string first ! $line]==0 } {
 	    switch [ProcCommand $line $file] {
 		format -  datum -  pformat -  dates - 
-		WP -  RT -  TR -  LN -
+		WP -  RT -  TR -  LN -  LAP -
 		GR {
 		    set LFileBuffFull($file) 1
 		    return [list $lps $segsts]
@@ -2082,48 +2131,66 @@ proc BadLNRead {file importing how} {
     return 1
 }
 
-proc FormGREls {lpertype} {
-    # form list of group elements (pairs of type, elements)
-    #  $lpertype is a list with sub-lists for each type in $TYPES
-    global TYPES
+proc BadLAPRead {file importing how} {
+    # parse LAP data from file in GPSMan format
+    #  $how in {normal, inGR}: keep data on all LAPs, keep data for LAPs
+    #    with indices in $LFileIxs($file,LAP)
+    global LFileLNo LFileDatum LFileId LFileOther LFilePFrmt LFileIxs MESS \
+	SUPPORTLAPS
 
-    set els ""
-    foreach wh $TYPES l $lpertype {
-	if { $l != "" } { lappend els [list $wh $l] }
+    if { ! $SUPPORTLAPS } {
+	GMMessage $MESS(lapncnsdrd)
+	return 0
     }
-    return $els
+    set id $LFileId($file)
+    set n [llength [set as $LFileOther($file)]]
+    foreach "dur dist begp endp cals trix" $as { break }
+    if { $n != 6 || [set start [CheckConvDate $id]] == "" || \
+	     ! [CheckTime GMMessage $dur] || \
+	     ( $dist != "" && ! [CheckFloat GMMessage $dist] ) || \
+	     ( $begp != "" && [set begp [ReadPosn $begp 0 $file]] == -1 ) || \
+	     ( $endp != "" && [set endp [ReadPosn $endp 0 $file]] == -1 ) || \
+	     ( $cals != "" && ! [CheckNumber GMMessage $cals] ) || \
+	     ( $trix != "" && \
+		   ( ! [CheckNumber GMMessage $trix] || $trix > 255 )) } {
+	GMMessage "$MESS(badLAP) $LFileLNo($file)"
+	return 1
+    }
+    set ix [IndexNamed LAP $id]
+    if { $how != "inGR" || \
+	     [lsearch -exact $LFileIxs($file,LAP) $ix] != -1 } {
+	set pfrmt $LFilePFrmt($file) ; set datum $LFileDatum($file)
+	set obs [ReadNB $file]
+	set data [FormData LAP \
+	      "Name Obs Start Dur Dist BegPosn EndPosn Cals TRIx PFrmt Datum" \
+		  [list $id $obs $start $dur $dist $begp $endp $cals $trix \
+		       $pfrmt $datum]]
+	StoreLAP $ix $id $data
+    }
+    return 0
 }
 
 proc LoadGRElements {file id} {
     # parse GR elements from file in GPSMan format
     #  $id is name of GR
-    global LFileEOF LFileLNo LFileId LFileBuffFull TYPES MESS
+    global LFileEOF LFileLNo LFileId LFileBuffFull TYPES SUPPORTLAPS MESS
 
-    foreach wh $TYPES { set l($wh) "" }
+    set gtypes [linsert $TYPES end LAP]
+    foreach wh $gtypes { set l($wh) "" }
     set wh 0
-    while { 1 } {
+    while 1 {
 	if { [SlowOpAborted] } { return "" }
 	set line [ReadFile $file]
-	if { $LFileEOF($file) } {
-	    set fl ""
-	    foreach wh $TYPES {
-		lappend fl $l($wh)
-	    }
-	    return [FormGREls $fl]
-	}
+	if { $LFileEOF($file) } { break }
 	set line [CleanLine $line 0]
 	if { [string length $line] > 0 } {
 	    if { [string first ! $line]==0 } {
 		switch -glob [set c [ProcCommand $line $file]] {
 		    format -  datum -  pformat -  dates - 
-		    WP -  RT -  TR -  LN -
+		    WP -  RT -  TR -  LN -  LAP -
 		    GR {
 			set LFileBuffFull($file) 1
-			set fl ""
-			foreach wh $TYPES {
-			    lappend fl $l($wh)
-			}
-			return [FormGREls $fl]
+			break
 		    }
 		    GRWP {
 			set wh WP
@@ -2167,6 +2234,14 @@ proc LoadGRElements {file id} {
 	    }
 	}
     }
+    set els ""
+    foreach wh $gtypes {
+	if { $l($wh) != "" && \
+	     ( $wh != "LAP" || $SUPPORTLAPS ) } {
+	    lappend els [list $wh $l($wh)]
+	}
+    }
+    return $els
 }
 
 proc BadGRRead {file keep} {
@@ -2205,7 +2280,7 @@ proc LoadAll {file} {
 		LoadWPs $file 1 0 normal
 		set r 1
 	    }
-	    RT -  TR -  LN {
+	    RT -  TR -  LN -  LAP {
 		if { $LFileDefs($file) != 7 } {
 		    GMMessage $MESS(noheader)
 		    break
@@ -2217,7 +2292,7 @@ proc LoadAll {file} {
 		if { [BadGRRead $file 1] } { break }
 		set r 1
 	    }
-	    GRWP -  GRRT -  GRTR -  GRLN -
+	    GRWP -  GRRT -  GRTR -  GRLN -  GRLAP -
 	    GRGR {
 		GMMessage "$MESS(GRelout) $LFileLNo($file)"
 	    }
@@ -2226,7 +2301,7 @@ proc LoadAll {file} {
 	    pformat -
 	    datum { }
 	    EOF { set r 1 ; break }
-	    NBC -
+	    pfdatum -  NBC -
 	    BAD {
 		GMMessage "$MESS(loaderr) $LFileLNo($file)"
 		break 
@@ -2242,7 +2317,7 @@ proc LoadAll {file} {
 
 proc LoadFile {what} {
     # open file in GPSMan format and load all items in it
-    #  $what in $TYPES or $what==Data identifies menu
+    #  $what in $TYPES or $what=="LAP" or $what==Data identifies menu
     #  (see proc LoadAll)
     # return 0 on error
     global LChannel
@@ -2257,7 +2332,7 @@ proc LoadFile {what} {
 
 proc LoadFileFrom {f what} {
     # open file in GPSMan format and load all items in it
-    #  $what in $TYPES or $what==Data
+    #  $what in $TYPES or $what=="LAP" or $what==Data
     #  (see proc LoadAll)
     # return 0 on error
     global LChannel CREATIONDATE
@@ -2294,7 +2369,7 @@ proc LoadGRElsIn {types lixs fmt} {
 		}
 		LoadWPs $file 1 0 $howWP
 	    }
-	    RT -  TR -  LN {
+	    RT -  TR -  LN -  LAP {
 		if { $LFileDefs($file) != 7 } {
 		    GMMessage $MESS(noheader)
 		    break
@@ -2304,7 +2379,7 @@ proc LoadGRElsIn {types lixs fmt} {
 	    GR {
 		if { [BadGRRead $file 0] } { break }
 	    }
-	    GRWP -  GRRT -  GRTR -  GRLN -
+	    GRWP -  GRRT -  GRTR -  GRLN -  GRLAP -
 	    GRGR {
 		GMMessage "$MESS(GRelout) $LFileLNo($file)"
 	    }
@@ -2313,7 +2388,7 @@ proc LoadGRElsIn {types lixs fmt} {
 	    pformat -
 	    datum { }
 	    EOF { break }
-	    NBC -
+	    pfdatum -  NBC -
 	    BAD {
 		GMMessage "$MESS(loaderr) $LFileLNo($file)"
 		break
@@ -2362,7 +2437,7 @@ proc LoadMapFixedBk {path} {
 	set f [GMOpenFile $TXT(loadfrm) MapBkInfo r]
     } else {
 	if { [catch {set f [open $path r]}] } {
-	    GMMessage "MESS(cantread) $path"
+	    GMMessage "$MESS(cantread) $path"
 	    return -1
 	}
     }
@@ -2433,10 +2508,11 @@ proc LoadMapInfo {path} {
     # try to load map information
     # if file does not start with !Map command, return 0
     #  otherwise, return -1 on error or abort, or on success a list with
-    #    datum pd td pformat scale 
+    #    datum pd td pformat pfdatum scale 
     #  where
     #    pd, pt are pairs with name and list of pairs with parameter
     #     name and value for projection and transformation
+    # for files generated by 6.1.2 or older $pfdatum defaults to $datum
     global LFileLNo LFileBuffFull LFileEOF LFileDatum LFileDefs \
 	    LFileProj LFileTransf LFilePFrmt LFileScale MESS TXT
 
@@ -2459,13 +2535,21 @@ proc LoadMapInfo {path} {
 	    if { [FindCommand $f] != "datum" } {
 		GMMessage $MESS(mbkbaddatum)
 	    } elseif { [FindCommand $f] != "mapproj" || \
-		    [FindCommand $f] != "maptransf" || \
-		    [FindCommand $f] != "pformat" || \
-		    [FindCommand $f] != "mapscale" } {
+			   [FindCommand $f] != "maptransf" || \
+			   [FindCommand $f] != "pformat" } {
 		GMMessage $MESS(badmapinfo)
 	    } else {
-		set r [list $LFileDatum($f) $LFileProj($f) $LFileTransf($f) \
-			$LFilePFrmt($f) $LFileScale($f)]
+		set datum $LFileDatum($f)
+		if { [set c [FindCommand $f]] != "pfdatum" } {
+		    # file by 6.1.2 or older
+		    set LFileDatum($f) $datum
+		} else { set c [FindCommand $f] }
+		if { $c != "mapscale" } {
+		    GMMessage $MESS(badmapinfo)
+		} else {
+		    set r [list $datum $LFileProj($f) $LFileTransf($f) \
+			$LFilePFrmt($f) $LFileDatum($f) $LFileScale($f)]
+		}
 	    }
 	}
 	ResetCursor .
