@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: garmin.tcl
-#  Last change:  22 October 2004
+#  Last change:  22 November 2004
 #
 # Includes contributions by
 #  - David Gardner (djgardner@users.sourceforge.net) marked "DJG contribution"
@@ -769,12 +769,14 @@ proc SendData {type args} {
 		    # assign numbers in a first-come first served way. If
 		    # some routes are numbered, then we cope with that too by
 		    # preallocating those numbers 
-		    if ($AutoNumRts) {
+                    if { $AutoNumRts } {
 			foreach rt [ array names RTIdNumber ] {
 			    set num $RTIdNumber($rt) 
-			    if { [regexp {^[0-9]+$} $RTIdNumber($rt)] } {
-				set $taken($num) 1;
-				set $RTSendNumber($rt) $num
+			    if { [regexp {^[0-9]+$} $num] } {
+				set $taken($num) 1
+				# MF change: no need for this here as
+				#  it must appear below when no $AutoNumRTs
+				# set $RTSendNumber($rt) $num
 			    }
 			}
 		    }
@@ -787,18 +789,20 @@ proc SendData {type args} {
 			    	if { ! $AutoNumRts } {
 				    incr badrts
 				    continue
-				} else {
-				    if {  [ catch {set RTSendNumber($rt)} ] } {
-					while { ! [catch \
+				}
+				if { [catch {set RTSendNumber($rt)}] } {
+				    while { ! [catch \
 						{set taken($RTNextNumber)}] } {
-					    incr RTNextNumber
-					}
-					set RTSendNumber($rt) $RTNextNumber
 					incr RTNextNumber
 				    }
+				    set RTSendNumber($rt) $RTNextNumber
+				    incr RTNextNumber
 				}
+			    } else {
+				# Alternative taken care of above
+				# MF change: ... only if $AutoNumRts
+				set RTSendNumber($rt) $RTIdNumber($rt)
 			    }
-			    # Alternative taken care of above.
 			} else {
 			    set RTSendNumber($rt) $RTIdNumber($rt)
 			}
@@ -1959,7 +1963,7 @@ proc InDataLAP {data} {
     # add LAPs data from receiver to database
     # create GRs with runs
     #  $data is a list of lists of values
-    global CurrPSPID GetSet LAPName LAPTRIx LAPName TXT
+    global CurrPSPID GetSet LAPName LAPTRIx TXT
 
     set pidd $CurrPSPID(LAPData)
     set ixs ""
@@ -1980,13 +1984,14 @@ proc InDataLAP {data} {
     foreach ix $ixs {
 	lappend run $LAPName($ix)
 	if { [set trix $LAPTRIx($ix)] < 255 } {
-	    set n "$TXT(run) $LAPName([lindex $run 0])"
-	    CreateGRFor "@$n@lapsrun" "" [list [list LAP $run]]
+	    set n "$TXT(lapsrun) [lindex $run 0]"
+	    CreateGRFor "@$n" "" [list [list LAP $run]]
 	    set run ""
 	}
     }
     if { $run != "" && $trix == 255 } {
-	CreateGRFor lapsrun "" [list [list LAP $run]]
+	set n "$TXT(lapsrun) [lindex $run 0]"
+	CreateGRFor "@$n" "" [list [list LAP $run]]
     }
     return
 }
@@ -2483,7 +2488,7 @@ proc HiddenCode {type val} {
 		set c "" ; append c [binary format "c" $x]
 		switch [HiddenCharCat $x] {
 		    copy { set code $c }
-		    escaped { set code "|$c" }
+		    escape { set code "|$c" }
 		    rubout { set code "|Z" }
 		}
 	    }
@@ -2517,7 +2522,7 @@ proc HiddenCharCat {b} {
     }
     if { $b < 33 } { return control }
     if { $b == 127 } { return rubout }
-    if { $b < 161 } { return upper_control}
+    if { $b < 161 } { return upper_control }
     return upper
 }
 
