@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: garmin_protocols.tcl
-#  Last change:  18 October 2004
+#  Last change:  22 November 2004
 #
 
 # description of Garmin protocols based on Garmin GPS Interface
@@ -298,6 +298,7 @@ array set PRODID {
     "Geko 201" 248
     "Geko 301" 256
     "Forerunner" 282
+    "GPSmap 276C" 285
     "GPSMap60C" 291
     "ForeTrex" 314
 }
@@ -387,6 +388,7 @@ array set PNAME {
     248  "Geko 201"
     256  "Geko 301"
     282  "Forerunner"
+    285  "GPSmap 276C"
     291  "GPSMap60C"
     314  "ForeTrex"
 }
@@ -487,6 +489,7 @@ array set PRTCLDEF {
     248  array
     256  diff
     282  array
+    285  see=291
     291  array
     314  array
 }
