@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2002 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: geod.tcl
-#  Last change:  17 January 2002
+#  Last change:  19 May 2004
 #
 
 ## Most of the geodetic information herein taken or adopted from
@@ -33,6 +33,8 @@
 #      Copyright (c) 1995 by Carsten Tschach (tschach@zedat.fu-berlin.de)
 #  International Institute for Aerospace Survey and Earth Sciences (ITC),
 #      Enschede, http://kartoweb.itc.nl/geometrics
+#  Land Information New Zealand (LINZ)
+#      http://www.linz.govt.nz/rcs/linz/pub/web/root/core/SurveySystem/GeodeticInfo/geodeticdatums/index.jsp
 ##
 #
 ## Some geodetic information kindly provided by
@@ -45,7 +47,7 @@
 #      - GPSTrackMaker by Odilon Ferreira (www.gpstm.com)
 ##
 #
-## New way of representing datums with NDATUM and ELLPSDDEF arrays, and
+## New way of representing datums with GDATUM and ELLPSDDEF arrays, and
 #   proc EllipsdData based on contribution by Stefan Heinen
 #   (stefan.heinen@djh-freeweb.de)
 ##
@@ -63,6 +65,14 @@ proc EllipsdData {datum} {
     return [lreplace $d 0 0 [lindex $def 0] [expr 1.0/[lindex $def 1]]]
 }
 
+proc EllipsdOf {datum} {
+    # return ellipsoid name for $datum or "" on error
+    global GDATUM
+
+    if { [catch {set e [lindex $GDATUM($datum) 0]}] } { return "" }
+    return $e
+}
+
 proc DatumRefId {datum} {
     # return reference id of $datum or -1 if unknown datum
     # if the reference id is a number it is the one used by GPStrans
@@ -72,21 +82,33 @@ proc DatumRefId {datum} {
     return [lindex $GDATUM($datum) 4]
 }
 
+proc DatumWithRefId {n} {
+    # return name of datum whose reference id is $n or -1 if there is none
+    # if the reference id is a number it is the one used by GPStrans
+    global GDATUM
+
+    foreach datum [array names GDATUM] {
+	if { [lindex $GDATUM($datum) 4] == $n } { return $datum }
+    }
+    return -1
+}
+
 # definitions of known datums and ellipsoids
 
 ###### known datums
      # when changing this list make sure you update the definitions below
 
-proc FillDatumMenu {menu commd} {
+proc FillDatumMenu {menu commd args} {
     # fill menu with known datum names
     # see proc FillMenu (utils.tcl) for the details on the arguments
+    #  $args not used
     global TXT UDatums
 
     set descr \
       [list "WGS 84" "WGS 72" \
 	--- \
 	@ [list Europe \
-                "Austrian (MGI)" "CH-1903" "Datum 73" \
+                Austrian "Austrian (MGI)" "CH-1903" "Datum 73" \
 		"Estonia Coord System 1937" "ED73" \
 		@ [list "European 1950" \
 		   "European 1950" "European 1950; Belgium" \
@@ -101,7 +123,8 @@ proc FillDatumMenu {menu commd} {
 		"European 1979" \
 		"Finland Hayford" "Graciosa Base SW 1948" "Hermannskogel" \
 		"Hermannskogel; old Yugoslavia" "Hjorsey 1955" "Ireland 1965" \
-		"Lisboa" "NTF (Nouvelle Triangulation de France)" \
+		"Lisboa" "NGO 1948" Norsk \
+	        "NTF (Nouvelle Triangulation de France)" \
 		"NTF (NTF ellipsoid)" \
 		"Observatorio 1966" \
 		@ [list "Ord Srvy Grt Britn" \
@@ -183,7 +206,7 @@ proc FillDatumMenu {menu commd} {
 		   "Arc 1960" "Arc 1960; Kenya" "Arc 1960; Kenya+Tanzania" \
 		   "Arc 1960; Tanzania"] \
 		"Astro DOS 71/4" "Ayabelle Lighthouse" \
-		"Bissau" "Cape" "Carthage" "Dabola" \
+		"Bissau" "Cape" "Carthage" "Dabola" "Egypt" \
 		"European 1950; Tunisia" "Leigon" \
 		"Liberia 1964" "M'Poraloko" "Massawa" \
 		"Merchich" "Minna" "Minna; Cameroon" "North Sahara 1959" \
@@ -292,7 +315,7 @@ array set GDATUM {
 
 "Ain el Abd 1970" { "International 1924"
     -150 -251 -2
-    2 "" -1 -1 -1 0}
+    2 "Mean for Bahrain Island, Saudi Arabia" -1 -1 -1 0}
 
 "Ain el Abd 1970; Bahrain" { "International 1924"
     -150 -250 -1
@@ -345,7 +368,7 @@ array set GDATUM {
 
 "Arc 1960" { "Clarke 1880"
     -160 -8 -300
-    5 "" -1 -1 -1 0}
+    5 "Kenya, Tanzania" -1 -1 -1 0}
 
 "Arc 1960; Kenya+Tanzania" { "Clarke 1880"
     -160 -6 -302
@@ -421,7 +444,7 @@ array set GDATUM {
 
 "CH-1903" { "Bessel 1841"
     674 15 405
-    21 ""}
+    21 "Switzerland"}
 
 "Chatham 1971" { "International 1924"
     175 -38 113
@@ -522,11 +545,11 @@ array set GDATUM {
 
 "Gandajika Base" { "International 1924"
     -133 -321 50
-    31 ""}
+    31 "Republic of Maldives"}
 
 "Geodetic Datum `49" { "International 1924"
     84 -22 209
-    32 "New Zealand" 5 3 5 14 -48 -33 165 180}
+    32 "NZGD49, New Zealand" 5 3 5 14 -48 -33 165 180}
 
 "Guam 1963" { "Clarke 1866"
     -100 -248 259
@@ -550,7 +573,7 @@ array set GDATUM {
 
 "Indian Thailand" { "Everest (India 1830)"
     214 836 303
-    38 ""}
+    38 "Thailand, Vietnam"}
 
 "Ireland 1965" { "Modified Airy"
     506 -122 611
@@ -891,7 +914,7 @@ array set GDATUM {
 
 "RT 90" { "Bessel 1841"
     498 -36 568
-    85 ""}
+    85 "Sweden"}
 
 "Santo (DOS)" { "International 1924"
     170 42 84
@@ -973,11 +996,11 @@ array set GDATUM {
 
 "Southeast Base" { "International 1924"
     -499 -249 314
-    92 ""}
+    92 "= Porto Santo 1936"}
 
 "Southwest Base" { "International 1924"
     -104 167 -38
-    93 ""}
+    93 "= Graciosa Base SW 1948"}
 
 "Timbalai 1948" { "Everest (Sabah Sarawak)"
     -679 669 -48
@@ -1156,7 +1179,8 @@ array set GDATUM {
 
 "Porto Santo 1936" { "International 1924"
     -499 -249 314
-    gm135 "Porto Santo, Madeira Islands" 25 25 25 2 31 35 -18 -15}
+    gm135 "Porto Santo, Madeira Islands; = Southeast Base"
+    25 25 25 2 31 35 -18 -15}
 
 "Pulkovo 1942" { "Krassovsky 1940"
     28 -130 -95
@@ -1244,7 +1268,7 @@ array set GDATUM {
 
 "Graciosa Base SW 1948" { "International 1924"
     -104 167 -38
-    gm150 "Azores (Faial, Graciosa, Pico, Sao Jorge, Terceira)"
+    gm150 "Azores (Faial, Graciosa, Pico, Sao Jorge, Terceira); = Southwest Base"
     3 3 3 5 37 41 -30 -26}
 
 "Hermannskogel" { "Bessel 1841 (Namibia)"
@@ -1290,6 +1314,22 @@ array set GDATUM {
 "European 1950; Belgium" { "International 1924"
     -126 80 -101
     gm160 "" -1 -1 -1 0}
+
+"Austrian" { "Bessel 1841"
+    594 84 471
+    gm161 ""}
+
+"Egypt" { "International 1924"
+    -133 -321 50
+    gm162 ""}
+
+"NGO 1948" { "Bessel 1841 (Norway)"
+    315 -217 528
+    gm163 ""}
+
+"Norsk" { "Bessel 1841 (Norway)"
+    278 93 474
+    gm164 ""}
 }
 
 ###### known ellipsoids
@@ -1306,7 +1346,8 @@ proc FillEllipsoidMenu {menu commd} {
               {Airy 1830} {Modified Airy}] \
          {Andrae 1876} {Appl. Physics. 1965} {Australian National} \
 	 @ [list Bessel \
-              {Bessel (Portugal)} {Bessel 1841} {Bessel 1841 (Namibia)}] \
+              {Bessel (Portugal)} {Bessel 1841} {Bessel 1841 (Namibia)} \
+	      {Bessel 1841 (Norway)}] \
          @ [list Clarke \
 	      {Clarke 1858} {Clarke 1866} {Clarke 1880}] \
          {Comm. des Poids et Mesures 1799} {Delambre 1810} {Engelis 1985} \
@@ -1360,6 +1401,8 @@ array set ELLPSDDEF {
 
 "Bessel 1841 (Namibia)" {6377483.865 299.1528128 ""}
 
+"Bessel 1841 (Norway)" {6377492.012 299.1528128 ""}
+
 "Clarke 1858" {6378363.63547 294.97870 "a=20926348 USft or ft?"}
 
 "Clarke 1866" {6378206.4   294.9786982 "used in North America"}
@@ -1407,7 +1450,7 @@ array set ELLPSDDEF {
 
 "Indonesian 1974" {6378160.0   298.247 ""}
 
-"International 1924" {6378388.0   297.0 "used in Europe"}
+"International 1924" {6378388.0   297.0 "used in Europe, New Zealand"}
 
 "Israeli" {6377973 293.466001939}
 
