@@ -17,12 +17,12 @@
 #      along with this program.
 #
 #  File: langdeutsch.tcl
-#  Last change:  10 May 2004
+#  Last change:  22 October 2004
 # German language file by Andreas Lange (Andreas.C.Lange@GMX.de)
 #  last input from him inserted: 31 January 2002
 #
 # Support by Sabine Broda (sbb@ncc.up.pt) since 2002
-#  last input from her inserted:  16 March 2004
+#  last input from her inserted:  22 March 2004
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
 
@@ -245,8 +245,7 @@ array set MESS {
     badinvproj "Nherungsfehler bei der Umkehrung der %s Projektion"
     negdlatlong "Lnge/Breite Werte drfen nicht negativ sein!"
     allundef "In der Gruppe sind keine Definitionen fr die WPe enthalten"
-    badfloats "Fliesskomma-Konvertierung funktioniert nicht korrekt; sind
-Sie sicher, dass Sie die Verbindung herstellen wollen?"
+    badfloats "Fliesskomma-Konvertierung funktioniert nicht korrekt; sind Sie sicher, dass Sie die Verbindung herstellen wollen?"
     frgetGRcs "Gruppe mit allen Elementen lschen?!"
     clrtrvlog "Reiseaufzeichnung lschen?"
     badattr "Unbekannter %s optionaler Feldname: %s"
@@ -271,6 +270,7 @@ Sie sicher, dass Sie die Verbindung herstellen wollen?"
     cantwrtimg "Fehler whrend Bildspeicherung in Datei in %s Format"
     TRsimplres "Vereinfachter TR mit Namen %s erzeugt"
     cantsaveRTid "%d RT(n) nicht gespeichert: non-numerisches Id"
+    cantsaveTRid "%d TR(n) nicht gespeichert: non-numerisches Id"
     badtrvconf "Ungltige Konfiguration; Neustart ohne Elemente"
     drvsimoff "Fahrsimulator: noch nicht gestartet!"
     needWP "Fahrsimulater: bitte erst einige WPe laden/definieren"
@@ -284,6 +284,12 @@ Sie sicher, dass Sie die Verbindung herstellen wollen?"
     RTnoWPname "WP in RT darf nicht mehr nur mit Namen identifiziert werden"
     distlarge "Zu grosse Entfernung"
     timeconsmg "Zeitaufwendige Aufgabe/Ttigkeit: fortfahren?"
+    badtimeval "Falscher Zeitwert"
+    badLAP "Ungltige Runde; Zeile"
+    lapncnsdrd "RND ignoriert"
+    undefinedTR   "Unbekannter TR"
+    emptymenu "Men hat keine Eintragung; fortsetzen?"
+    cantwrtsymenu "Kann die nutzerdefinierte Symbolmen Datei nicht schreiben"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} Grad {$ALUNIT} Etappe Bezeichnung"
@@ -887,7 +893,6 @@ array set TXT {
     Ghidden_map_area "Karten-Flche"
     Ghidden_map_int "Karten-Kreuzung"
     Ghidden_map_addr "Karten-Adresse"
-    Ghidden_map_label "Karten-Kennzeichen"
     Ghidden_map_line "Karten-Linie"
     Ghidden_locked blockiert
     Ghidden_default "Vorgabe"
@@ -1063,6 +1068,118 @@ array set TXT {
     SYpin_red "Nadel, rot"
     ozimapfile "Ozi Map Datei"
     info "Information"
+    syhlpbx "Rechte Taste zur Wiederordnung\nvon Elementen der Liste benutzen"
+    optDEFMAPPFDATUM "Kartenkoordinaten Datum"
+    mkgrp "Gruppe erzeugen"
+    dispitems "Aufgezeichnete Elemente"
+    hiditems "Nicht aufgezeichnete Elemente"
+    Ghidden_transparent Transparent
+    Ghidden_temp Temperatur
+    Ghidden_time "Zeit"
+    Ghidden_cat Categorie
+    SYopen_24hr "Geffnet von 0 bis 24"
+    SYbot_cond "Meeresgrund Konditionen"
+    SYbeacon "Leuchtfeuer"
+    SYreef "Riff"
+    SYweedbed "Seegrser"
+    SYdock "Dock"
+    SYmarina "Anlegestelle"
+    SYbait_tackle "Fischkder und Angelzeug"
+    SYstump "Stumpf"
+    SYcntct_ball_cap "Baseballmtze"
+    SYcntct_big_ears "Grosse Ohren"
+    SYcntct_spike "Spike"
+    SYcntct_goatee "Spitzbart"
+    SYcntct_dreads "Zpfe"
+    SYcntct_female1 "Frau 1"
+    SYcntct_female2 "Frau 2"
+    SYcntct_female3 "Frau 3"
+    SYcntct_pirate "Pirat"
+    SYcntct_biker "Radfahrer"
+    SYcntct_alien "Alien"
+    SYcntct_bug "Insekt"
+    SYcntct_cat "Katze"
+    SYcntct_dog "Hund"
+    SYcntct_pig "Schwein"
+    SYhydrant "Hydrant"
+    SYcircle_blue "Kreis, blau"
+    SYcircle_green "Kreis, grn"
+    SYcircle_red "Kreis, rot"
+    SYdiamond_blue "Diamant, blau"
+    SYoval_blue "Oval, blau"
+    SYoval_green "Oval, grn"
+    SYoval_red "Oval, rot"
+    SYrect_blue "Block, blau"
+    SYrect_green "Block, grn"
+    SYrect_red "Block, rot"
+    SYsquare_blue "Rechteck, blau"
+    SYtriangle_blue "Dreieck, blau"
+    SYtriangle_green "Dreieck, grn"
+    SYtriangle_red "Dreieck, rot"
+    SYletter_a_blue "A, blau"
+    SYletter_a_green "A, grn"
+    SYletter_a_red "A, rot"
+    SYletter_b_blue "B, blau"
+    SYletter_b_green "B, grn"
+    SYletter_b_red "B, rot"
+    SYletter_c_blue "C, blau"
+    SYletter_c_green "C, grn"
+    SYletter_c_red "C, rot"
+    SYletter_d_blue "D, blau"
+    SYletter_d_green "D, grn"
+    SYletter_d_red "D, rot"
+    SYnumber_0_blue "0, blau"
+    SYnumber_0_green "0, grn"
+    SYnumber_0_red "0, rot"
+    SYnumber_1_blue "1, blau"
+    SYnumber_1_green "1, grn"
+    SYnumber_1_red "1, rot"
+    SYnumber_2_blue "2, blau"
+    SYnumber_2_green "2, grn"
+    SYnumber_2_red "2, rot"
+    SYnumber_3_blue "3, blau"
+    SYnumber_3_green "3, grn"
+    SYnumber_3_red "3, rot"
+    SYnumber_4_blue "4, blau"
+    SYnumber_4_green "4, grn"
+    SYnumber_4_red "4, rot"
+    SYnumber_5_blue "5, blau"
+    SYnumber_5_green "5, grn"
+    SYnumber_5_red "5, rot"
+    SYnumber_6_blue "6, blau"
+    SYnumber_6_green "6, grn"
+    SYnumber_6_red "6, rot"
+    SYnumber_7_blue "7, blau"
+    SYnumber_7_green "7, grn"
+    SYnumber_7_red "7, rot"
+    SYnumber_8_blue "8, blau"
+    SYnumber_8_green "8, grn"
+    SYnumber_8_red "8, rot"
+    SYnumber_9_blue "9, blau"
+    SYnumber_9_green "9, grn"
+    SYnumber_9_red "9, rot"
+    items "Elemente"
+    syusrmenu "Nutzerdefiniertes Symbolmen"
+    cfgsymenu "Konfigurieren des nutzerdefinierten Symbolmens"
+    insmnb   "Untermen vorher einfgen"
+    insmna   "Untermen hinterher einfgen"
+    opensbmn "Untermen ffnen"
+    clssbmn  "Untermen schliessen"
+    optSUPPORTLAPS "Rundenuntersttzung"
+    LAP  RND
+    nameLAP "Runde"
+    duration "Zeitdauer"
+    calrs "Kalorien"
+    getLAP  "Empfangen der Runden"
+    optAutoNumRts "Autom. Num. der RTs beim Senden"
+    SYfhs_facility "FHS facility"
+    SYtide_pred_stn "Gezeiten-Strmungsstation"
+    SYanchor_prohib "Ankern verboten"
+    SYcoast_guard "Kstenpolizei"
+    SYdropoff "Dropoff"
+    SYcntct_afro "Afro"
+    SYcntct_ranger "Ranger"
+    numberfrom0 "Zhler auf 1 stellen"
 }
 
     # the following definitions must be coherent with $TXT
@@ -1074,6 +1191,7 @@ array set INVTXT {
     WP   WP
     RT   RT
     TR   TR
+    RND  LAP
     GR   GR
 }
 
