@@ -17,13 +17,14 @@
 #      along with this program.
 #
 #  File: langengl.tcl
-#  Last change:  31 May 2004
+#  Last change:  20 October 2004
 #
 # Includes contributions by
 #  - Brian Baulch (baulchb@onthenet.com.au)
 #  - Matt Martin (matt.martin@ieee.org)
 #  - Jean H Theoret (ve2za@rac.ca)
 #  - Valere Robin (valere.robin@wanadoo.fr)
+#  - David Gardner (djgardner@users.sourceforge.net)
 
 # only 3 chars long names; check also ALLMONTH in file gpsman
 set MONTHNAMES "Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec"
@@ -75,6 +76,7 @@ array set MESS {
     badcommdWP   "Bad command when loading WPs; line"
     notabsWP   "Bad WP definition; no tabs, line"
     undefinedWP   "Reference to unknown WP: %s"
+    undefinedTR   "Unknown TR"
     nofieldsWP   "Bad WP, not enough fields; line"
     excfieldsWP  "Bad WP, too many fields; line"
     badWPsRT   "RT with bad waypoints list; line"
@@ -130,6 +132,7 @@ array set MESS {
     getWP   "Getting WPoints"
     getRT   "Getting Routes"
     getTR   "Getting Tracks"
+    getLAP  "Getting Laps"
     putWP   "Putting WPoints"
     putRT   "Putting Routes"
     putTR   "Putting Tracks"
@@ -265,6 +268,7 @@ array set MESS {
     unobscmap "Error probably because there is a window/icon over the map; retry after delay?"
     cantwrtimg "Error writing image to file in %s format"
     cantsaveRTid "%d RT(s) not saved: non-numeric identifier"
+    cantsaveTRid "%d TR(s) not saved: non-numeric identifier"
     badtrvconf "Corrupt configuration; restarting with empty one"
     drvsimoff "Driving simulator: not started yet!"
     needWP "Driving simulator: please load or define some WPs first"
@@ -280,6 +284,11 @@ array set MESS {
     badconv "Could not convert value for parameter %s: %s"
     badprmval "Wrong converted value for parameter %s: %s"
     timeconsmg "Time consuming operation: go on?"
+    badtimeval "Bad time value"
+    badLAP "Bad LAP; line"
+    lapncnsdrd "LAP not considered"
+    emptymenu "Empty menu; continue?"
+    cantwrtsymenu "Cannot write symbol menu file"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg {$ALUNIT} stage label"
@@ -432,6 +441,9 @@ array set TXT {
     opt_Formats   "Units and formats"
     optDISTUNIT   "Distance"
     optALTUNIT "Altitude"
+    optUSESLOWOPWINDOW "Window to control slow operations"
+    optDEFTRECPROTOCOL "Default protocol"
+    optLNSREACT "Mapped LNs react to mouse"
     M     m
     KM    km
     NAUTMILE    "nautical mile"
@@ -535,6 +547,7 @@ array set TXT {
     TR   TR
     LN   LN
     GR   GR
+    LAP  LAP
     commrec   "Communication with receiver"
     abort   Abort
     ACKs   ACKs
@@ -554,16 +567,19 @@ array set TXT {
     mpbkgrcs "Grid position"
     nameImage Image
     symbol Symbol
+    SY1st_aid "First aid"
+    SYCATaviation Aviation
     SYCATgeneral "General use"
     SYCATland Land
     SYCATwater Water
-    SYCATaviation Aviation
-    SY1st_aid "First aid"
+    SYMOB "Man over board"
+    SYRV_park "Recreational Vehicle park"
     SYWP_buoy_white "Buoy, white"
     SYWP_dot "WP"
     SYairport "Airport"
     SYamusement_park "Amusement park"
     SYanchor "Anchor"
+    SYanchor_prohib "Anchor prohibited"
     SYavn_danger "Danger (avn)"
     SYavn_faf "1st approach fix"
     SYavn_lom "Localizer outer marker"
@@ -573,13 +589,16 @@ array set TXT {
     SYavn_vor "VHF omni-range"
     SYavn_vordme "VOR-DME"
     SYavn_vortac "VOR/TACAN"
+    SYbait_tackle "Bait and tackle"
     SYball "Ball"
     SYbeach "Beach"
+    SYbeacon "Beacon"
     SYbell "Bell"
     SYbiker "Biker"
     SYboat "Boat"
     SYboat_ramp "Boat ramp"
     SYborder "Border crossing"
+    SYbot_cond "Bottom conditions"
     SYbowling "Bowling"
     SYbox_blue "Box, blue"
     SYbox_green "Box, green"
@@ -610,26 +629,54 @@ array set TXT {
     SYcemetery "Cemetery"
     SYchapel "Chapel"
     SYchurch "Church"
+    SYcircle_blue "Circle, blue"
+    SYcircle_green "Circle, green"
+    SYcircle_red "Circle, red"
     SYcircle_x "Circled X"
     SYcivil "Civil location"
+    SYcntct_afro "Afro"
+    SYcntct_alien "Alien"
+    SYcntct_ball_cap "Ball cap"
+    SYcntct_big_ears "Big ear"
+    SYcntct_biker "Biker"
+    SYcntct_bug "Bug"
+    SYcntct_cat "Cat"
+    SYcntct_dog "Dog"
+    SYcntct_dreads "Dreads"
+    SYcntct_female1 "Female 1"
+    SYcntct_female2 "Female 2"
+    SYcntct_female3 "Female 3"
+    SYcntct_goatee "Goatee"
+    SYcntct_kung_fu "Kung fu"
+    SYcntct_pig "Pig"
+    SYcntct_pirate "Pirate"
+    SYcntct_ranger "Ranger"
+    SYcntct_smiley "Smiley"
+    SYcntct_spike "Spike"
+    SYcntct_sumo "Sumo"
+    SYcoast_guard "Coast guard"
     SYcontrolled "Controlled Area"
     SYcrossing "Crossing"
     SYdam "Dam"
     SYdanger "Danger"
     SYdeer "Deer"
+    SYdiamond_blue "Diamond, blue"
     SYdiamond_green "Diamond, green"
     SYdiamond_red "Diamond, red"
     SYdiver_down_1 "Diver down 1"
     SYdiver_down_2 "Diver down 2"
+    SYdock "Dock"
     SYdollar "Dollar"
     SYdot "Dot"
     SYdrinking_water "Drinking water"
+    SYdropoff "Dropoff"
     SYduck "Duck"
     SYelevation "Elevation"
-    SYexit_no_serv "Exit, no services"
     SYexit "Exit"
+    SYexit_no_serv "Exit, no services"
     SYfactory "Factory"
     SYfastfood "Fast food"
+    SYfhs_facility "FHS facility"
     SYfish "Fish"
     SYfitness "Fitness"
     SYflag "Flag"
@@ -639,17 +686,18 @@ array set TXT {
     SYfreeway "Freeway"
     SYfuel "Fuel"
     SYfuel_store "Fuel & store"
-    SYgeocache "Geocache"
-    SYgeocache_fnd "Geocache found"
     SYgeo_name_land "Geo name, land"
     SYgeo_name_man "Geo name, man-made"
     SYgeo_name_water "Geo name, water"
+    SYgeocache "Geocache"
+    SYgeocache_fnd "Geocache found"
     SYglider "Glider"
     SYgolf "Golf"
     SYheliport "Heliport"
     SYhorn "Horn"
     SYhouse "House"
     SYhouse_2 "House 2"
+    SYhydrant "Water hydrant"
     SYice_skating "Ice skating"
     SYinfo "Info"
     SYintersection "Intersection"
@@ -660,17 +708,29 @@ array set TXT {
     SYlarge_city "City, large"
     SYlarge_exit_ns "Exit no serv, large"
     SYlarge_ramp_int "Ramp int, large"
+    SYletter_a_blue "A, blue"
+    SYletter_a_green "A, green"
+    SYletter_a_red "A, red"
+    SYletter_b_blue "B, blue"
+    SYletter_b_green "B, green"
+    SYletter_b_red "B, red"
+    SYletter_c_blue "C, blue"
+    SYletter_c_green "C, green"
+    SYletter_c_red "C, red"
+    SYletter_d_blue "D, blue"
+    SYletter_d_green "D, green"
+    SYletter_d_red "D, red"
     SYlevee "Levee"
     SYlight "Light"
     SYlodging "Lodging"
     SYmany_fish "Fish bank"
     SYmany_tracks "Many tracks"
+    SYmarina "Marina"
     SYmark_x "Mark, x"
     SYmedium_city "City, medium"
     SYmile_marker "Mile marker"
     SYmilitary "Military location"
     SYmine "Mine"
-    SYMOB "Man over board"
     SYmonument "Monument"
     SYmountains "Mountains"
     SYmovie "Movie"
@@ -679,7 +739,41 @@ array set TXT {
     SYntl_highway "National highway"
     SYnull "(transparent)"
     SYnull_2 "(void)"
+    SYnumber_0_blue "0, blue"
+    SYnumber_0_green "0, green"
+    SYnumber_0_red "0, red"
+    SYnumber_1_blue "1, blue"
+    SYnumber_1_green "1, green"
+    SYnumber_1_red "1, red"
+    SYnumber_2_blue "2, blue"
+    SYnumber_2_green "2, green"
+    SYnumber_2_red "2, red"
+    SYnumber_3_blue "3, blue"
+    SYnumber_3_green "3, green"
+    SYnumber_3_red "3, red"
+    SYnumber_4_blue "4, blue"
+    SYnumber_4_green "4, green"
+    SYnumber_4_red "4, red"
+    SYnumber_5_blue "5, blue"
+    SYnumber_5_green "5, green"
+    SYnumber_5_red "5, red"
+    SYnumber_6_blue "6, blue"
+    SYnumber_6_green "6, green"
+    SYnumber_6_red "6, red"
+    SYnumber_7_blue "7, blue"
+    SYnumber_7_green "7, green"
+    SYnumber_7_red "7, red"
+    SYnumber_8_blue "8, blue"
+    SYnumber_8_green "8, green"
+    SYnumber_8_red "8, red"
+    SYnumber_9_blue "9, blue"
+    SYnumber_9_green "9, green"
+    SYnumber_9_red "9, red"
     SYoil_field "Oil field"
+    SYopen_24hr "Open 24 hours"
+    SYoval_blue "Block, blue"
+    SYoval_green "Block, green"
+    SYoval_red "Block, red"
     SYparachute "Parachute"
     SYpark "Park"
     SYparking "Parking"
@@ -695,9 +789,12 @@ array set TXT {
     SYprivate "Private field"
     SYradio_beacon "Radio beacon"
     SYramp_int "Ramp intersection"
+    SYrect_blue "Block, blue"
+    SYrect_green "Block, green"
+    SYrect_red "Block, red"
+    SYreef "Reef"
     SYrestricted "Restricted Area"
     SYrestrooms "WC"
-    SYRV_park "Recreational Vehicle park"
     SYscenic "Scenic"
     SYschool "School"
     SYseaplane "Seaplane base"
@@ -709,27 +806,34 @@ array set TXT {
     SYsmall_city "City, small"
     SYsnow_skiing "Snow skiing"
     SYsoft_field "Soft field"
+    SYsquare_blue "Square, blue"
     SYsquare_green "Square, green"
     SYsquare_red "Square, red"
     SYst_highway "State highway"
     SYstadium "Stadium"
     SYstore "Store"
     SYstreet_int "Street intersection"
+    SYstump "Stump"
     SYsummit "Summit"
     SYswimming "Swimming"
     SYtake_off "Take-off"
     SYtall_tower "Tower, tall"
     SYtheater Theater
+    SYtide_pred_stn "Tide/current pred station"
     SYtoll Toll
     SYtow_truck "Tow truck"
     SYtraceback "Trace-back"
     SYtracks Tracks
     SYtrail_head "Trail head"
     SYtree "Tree"
+    SYtriangle_blue "Triangle, blue"
+    SYtriangle_green "Triangle, green"
+    SYtriangle_red "Triangle, red"
     SYtruck_stop "Truck stop"
     SYtunnel "Tunnel"
     SYultralight "Ultralight"
     SYus_highway "US highway"
+    SYweedbed "Weedbed"
     SYweight_station "Weight station"
     SYwreck "Wreck"
     SYzoo "Zoo"
@@ -1068,7 +1172,6 @@ array set TXT {
     Ghidden_map_area "Map area"
     Ghidden_map_int "Map intersection"
     Ghidden_map_addr "Map address"
-    Ghidden_map_label "Map label"
     Ghidden_map_line "Map line"
     Ghidden_locked Locked
     Ghidden_default "Default"
@@ -1088,15 +1191,20 @@ array set TXT {
     Ghidden_dark_cyan "Dark cyan"
     Ghidden_light_gray "Light grey"
     Ghidden_dark_gray "Dark grey"
+    Ghidden_transparent Transparent
     Ghidden_line Line
     Ghidden_link Stage
     Ghidden_net Net
     Ghidden_direct Direct
     Ghidden_snap Snap
+    Ghidden_temp Temperature
+    Ghidden_time "Time stamp"
+    Ghidden_cat Category
     renres "RENAMED"
     forgetGRcs "Forget GR&Els"
     optDEFMAPPROJ "Map projection"
     optDEFMAPPFRMT "Map coordinates"
+    optDEFMAPPFDATUM "Map coordinates datum"
     undo Undo
     UTMzone zone
     tfwfile  "TFW file"
@@ -1127,6 +1235,27 @@ array set TXT {
     ozimapfile "Ozi Map file"
     info "Information"
     climbrate  "Climb rate"
+    BGAfeature  "Feature"
+    BGAfindblty "Findability"
+    BGAairact   "Air activity"
+    dispitems "Displayed items"
+    hiditems "Hidden items"
+    mkgrp "Make Group"
+    optAutoNumRts "Auto-number RTs when putting"
+    numberfrom0 "Set counter to 1"
+    items "Items"
+    optSUPPORTLAPS "Support for laps"
+    nameLAP "Lap"
+    duration "Duration"
+    calrs "Calories"
+    syusrmenu "Custom symbol menu"
+    cfgsymenu "Configure custom symbol menu"
+    insmnb   "Insert sub-menu before"
+    insmna   "Insert sub-menu after"
+    opensbmn "Open sub-menu"
+    clssbmn  "Close sub-menu"
+    syhlpbx "Use right-button to\nreorder list elements"
+    lapsrun Run
 }
 
     # the following definitions must be coherent with $TXT
@@ -1142,6 +1271,7 @@ array set INVTXT {
     TR   TR
     LN   LN
     GR   GR
+    LAP  LAP
     m    M
     ft   FT
 }
