@@ -17,10 +17,10 @@
 #      along with this program.
 #
 #  File: langes.tcl
-#  Last change:  1 June 2004
+#  Last change:  20 October 2004
 #
 # Spanish language file by Alberto Morales (amd77@gulic.org)
-#  last input from him: 1 June 2004
+#  last input from him: 20 October 2004
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -262,6 +262,7 @@ array set MESS {
     cantwrtimg "Error al guardar imagen a fichero en formato %s"
     TRsimplres "TR resultante de simplificacin creado con nombre %s"
     cantsaveRTid "%d RT(s) no guardada: identificador no numrico"
+    cantsaveTRid "%d TR(s) no guardado: identificador no numrico"
     badtrvconf "Configuracin inconsistente sustituida por una vaca"
     drvsimoff "Simulador de conduccin: falta iniciar!"
     needWP "Simulador de conduccin: es preciso definir PTs antes"
@@ -273,6 +274,12 @@ array set MESS {
     RTnoWPname "Los puntos de ruta slo con nombre han dejado de estar soportados"
     distlarge "Distancia demasiado grande!"
     timeconsmg "La operacin puede durar mucho tiempo: seguir?"
+    badtimeval "Valor incorrecto para la hora"
+    badLAP "LAP incorrecto; lnea"
+    lapncnsdrd "LAP no se toma en cuenta"
+    undefinedTR   "Trayecto desconocido"
+    emptymenu "Men vacio; continuar?"
+    cantwrtsymenu "No puedo escribir en fichero de men de smbolos"
 }
 
 set TXT(RTcompflds) "# PT {$DTUNIT} grados {$ALUNIT} etapa etiq"
@@ -1036,7 +1043,6 @@ array set TXT {
     Ghidden_map_area "rea (mapa)"
     Ghidden_map_int "Interseccin (mapa)"
     Ghidden_map_addr "Direccin (mapa)"
-    Ghidden_map_label "Etiqueta (mapa)"
     Ghidden_map_line "Lnea (mapa)"
     Ghidden_locked Bloqueado
     Ghidden_default "Normal"
@@ -1096,6 +1102,127 @@ array set TXT {
     ozimapfile "fichero Ozi Map"
     info "Informacin"
     climbrate "Ritmo de Ascenso"
+    optUSESLOWOPWINDOW "Ventana para controlar operaciones lentas"
+    optDEFTRECPROTOCOL "Protocolo por defecto"
+    optLNSREACT "LNs asociadas responden al ratn"
+    BGAfeature  "BGA Caracterstica"
+    BGAfindblty "BGA Encontrabilidad"
+    BGAairact   "BGA Actividad aerea"
+    syhlpbx "Usar botn derecho para\nreordenar los elementos de la lista"
+    optDEFMAPPFDATUM "Datum de coordenadas del mapa"
+    mkgrp "Crear Grupo"
+    dispitems "Elementos mostrados"
+    hiditems "Elementos ocultos"
+    optAutoNumRts "Numerar Rutas automticamente al enviar"
+    Ghidden_transparent Transparente
+    Ghidden_temp Temperatura
+    Ghidden_time "Marca de tiempo"
+    Ghidden_cat Categora
+    SYopen_24hr "Abierto 24h"
+    SYfhs_facility "Instalacin FHS"
+    SYbot_cond "Condiciones fondo"
+    SYtide_pred_stn "Estacin prediccin mareas/corrientes"
+    SYanchor_prohib "Ancla prohibida"
+    SYbeacon "Baliza"
+    SYcoast_guard "GuardaCostas"
+    SYreef "Arrecife"
+    SYweedbed "Lecho de algas"
+    SYdropoff "Embarcadero"
+    SYdock "Drsena"
+    SYmarina "Marina"
+    SYbait_tackle "Cebo y aparejo"
+    SYstump "Tocn"
+    SYcntct_smiley "Sonriente"
+    SYcntct_ball_cap "Pelota beisbol"
+    SYcntct_big_ears "Orejas grandes"
+    SYcntct_spike "Clavo"
+    SYcntct_goatee "Perilla"
+    SYcntct_afro "Afro"
+    SYcntct_dreads "Trencitas"
+    SYcntct_female1 "Hembra 1"
+    SYcntct_female2 "Hembra 2"
+    SYcntct_female3 "Hembra 3"
+    SYcntct_ranger "Ranger"
+    SYcntct_kung_fu "Kung fu"
+    SYcntct_sumo "Sumo"
+    SYcntct_pirate "Pirata"
+    SYcntct_biker "Ciclista"
+    SYcntct_alien "Alien"
+    SYcntct_bug "Cucaracha"
+    SYcntct_cat "Gato"
+    SYcntct_dog "Perro"
+    SYcntct_pig "Cerdo"
+    SYhydrant "Boca de riego"
+    SYcircle_blue "Crculo, azul"
+    SYcircle_green "Crculo, verde"
+    SYcircle_red "Crculo, rojo"
+    SYdiamond_blue "Rombo, azul"
+    SYoval_blue "Oval, azul"
+    SYoval_green "Oval, verde"
+    SYoval_red "Oval, rojo"
+    SYrect_blue "Bloque, azul"
+    SYrect_green "Bloque, verde"
+    SYrect_red "Bloque, rojo"
+    SYsquare_blue "Cuadrado, azul"
+    SYtriangle_blue "Tringulo, azul"
+    SYtriangle_green "Tringulo, verde"
+    SYtriangle_red "Tringulo, rojo"
+    SYletter_a_blue "A, azul"
+    SYletter_a_green "A, verde"
+    SYletter_a_red "A, rojo"
+    SYletter_b_blue "B, azul"
+    SYletter_b_green "B, verde"
+    SYletter_b_red "B, rojo"
+    SYletter_c_blue "C, azul"
+    SYletter_c_green "C, verde"
+    SYletter_c_red "C, rojo"
+    SYletter_d_blue "D, azul"
+    SYletter_d_green "D, verde"
+    SYletter_d_red "D, rojo"
+    SYnumber_0_blue "0, azul"
+    SYnumber_0_green "0, verde"
+    SYnumber_0_red "0, rojo"
+    SYnumber_1_blue "1, azul"
+    SYnumber_1_green "1, verde"
+    SYnumber_1_red "1, rojo"
+    SYnumber_2_blue "2, azul"
+    SYnumber_2_green "2, verde"
+    SYnumber_2_red "2, rojo"
+    SYnumber_3_blue "3, azul"
+    SYnumber_3_green "3, verde"
+    SYnumber_3_red "3, rojo"
+    SYnumber_4_blue "4, azul"
+    SYnumber_4_green "4, verde"
+    SYnumber_4_red "4, rojo"
+    SYnumber_5_blue "5, azul"
+    SYnumber_5_green "5, verde"
+    SYnumber_5_red "5, rojo"
+    SYnumber_6_blue "6, azul"
+    SYnumber_6_green "6, verde"
+    SYnumber_6_red "6, rojo"
+    SYnumber_7_blue "7, azul"
+    SYnumber_7_green "7, verde"
+    SYnumber_7_red "7, rojo"
+    SYnumber_8_blue "8, azul"
+    SYnumber_8_green "8, verde"
+    SYnumber_8_red "8, rojo"
+    SYnumber_9_blue "9, azul"
+    SYnumber_9_green "9, verde"
+    SYnumber_9_red "9, rojo"
+    numberfrom0 "Configurar contador a 0"
+    items "Elementos"
+    syusrmenu "Personalizar men de smbolo"
+    cfgsymenu "Configurar men de smbolo"
+    insmnb   "Inserta submen antes"
+    insmna   "Inserta submen despus"
+    opensbmn "Abrir submen"
+    clssbmn  "Cerrar submen"
+    optSUPPORTLAPS "Soporte para Vueltas"
+    LAP  LAP
+    nameLAP "Vuelta"
+    duration "Duracin"
+    calrs "Caloras"
+    getLAP  "Obteniendo Vueltas"
 }
 
     # the following definitions must be coherent with $TXT
@@ -1109,6 +1236,7 @@ array set INVTXT {
     PT   WP
     RT   RT
     TR   TR
+    LAP  LAP
     GR   GR
 }
 
