@@ -17,11 +17,11 @@
 #      along with this program.
 #
 #  File: langengl.tcl
-#  Last change:  16 October 2004
+#  Last change:  27 October 2004
 #
 # French language file by Valre Robin (valere.robin@wanadoo.fr)
 #  Last change by him:  11 November 2001
-#  last input from him inserted:  13 July 2004
+#  last input from him inserted:  27 July 2004
 #
 # Includes contributions by Jean H Theoret (ve2za@rac.ca)
 # Includes typo corrections by Laurent Bonnaud (bonnaud@lis.inpg.fr)
@@ -272,6 +272,12 @@ array set MESS {
     RTnoWPname "Un point d'une route ne peux plus tre dsign uniquement par son nom"
     distlarge "Distance trop grande!"
     timeconsmg "Opration potentiellement longue: continuer?"
+    badtimeval "Mauvaise heure"
+    badLAP "tapes errones"
+    lapncnsdrd "tapes non lues"
+    undefinedTR   "TR inconnu"
+    emptymenu "Menu vide; continuer?"
+    cantwrtsymenu "Impossible d'criture le fichier des menus de symboles"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg {$ALUNIT} stage label"
@@ -1093,6 +1099,121 @@ array set TXT {
     optDEFTRECPROTOCOL "Protocole par dfaut"
     optLNSREACT "Les lignes sur la carte sont cliquable  la souris"
     syhlpbx "Utiliser le bouton droit pour\nrordonnancer les lments de la liste"
+    optDEFMAPPFDATUM "Donnes pour les coordonnes de la carte"
+    mkgrp "Crer un groupe"
+    dispitems "Elments affichs"
+    hiditems "Elments cachs"
+    optAutoNumRts "Numrotation automatique des routes pour le chargement"
+    Ghidden_transparent Transparent
+    Ghidden_temp "Temprature"
+    Ghidden_time "Estampille temporelle"
+    Ghidden_cat Categorie
+    SYopen_24hr "Ouvert 24/24"
+    SYfhs_facility "Etablissement FHS"
+    SYbot_cond "Conditions de fond"
+    SYtide_pred_stn "Station de prvision des courants et mares"
+    SYanchor_prohib "Mouillage interdit"
+    SYbeacon "Balise"
+    SYcoast_guard "Garde-cte"
+    SYreef "Rcif"
+    SYweedbed "Weedbed"
+    SYdropoff "Embarcadre"
+    SYdock "Dock"
+    SYmarina "Marina"
+    SYbait_tackle "Appts et quipement de pche"
+    SYstump "Tronc"
+    SYcntct_smiley "Smiley"
+    SYcntct_ball_cap "Casquette de baseball"
+    SYcntct_big_ears "Grande oreille"
+    SYcntct_spike "Clou"
+    SYcntct_goatee "Bouc"
+    SYcntct_afro "Afro"
+    SYcntct_dreads "Dreadlocks"
+    SYcntct_female1 "Femme 1"
+    SYcntct_female2 "Femme 2"
+    SYcntct_female3 "Femme 3"
+    SYcntct_ranger "Garde forrestier"
+    SYcntct_kung_fu "Kung fu"
+    SYcntct_sumo "Sumo"
+    SYcntct_pirate "Pirate"
+    SYcntct_biker "Cycliste"
+    SYcntct_alien "Alien"
+    SYcntct_bug "Insecte"
+    SYcntct_cat "Chat"
+    SYcntct_dog "Chien"
+    SYcntct_pig "Cochon"
+    SYhydrant "Pompe incendie"
+    SYcircle_blue "Cercle, bleu"
+    SYcircle_green "Cercle, vert"
+    SYcircle_red "Cercle, rouge"
+    SYdiamond_blue "Diamand, bleu"
+    SYoval_blue "Ovale, bleu"
+    SYoval_green "Ovale, vert"
+    SYoval_red "Ovale, rouge"
+    SYrect_blue "Bloc, bleu"
+    SYrect_green "Bloc, vert"
+    SYrect_red "Bloc, rouge"
+    SYsquare_blue "Carr, bleu"
+    SYtriangle_blue "Triangle, bleu"
+    SYtriangle_green "Triangle, vert"
+    SYtriangle_red "Triangle, rouge"
+    SYletter_a_blue "A, bleu"
+    SYletter_a_green "A, vert"
+    SYletter_a_red "A, rouge"
+    SYletter_b_blue "B, bleu"
+    SYletter_b_green "B, vert"
+    SYletter_b_red "B, rouge"
+    SYletter_c_blue "C, bleu"
+    SYletter_c_green "C, vert"
+    SYletter_c_red "C, rouge"
+    SYletter_d_blue "D, bleu"
+    SYletter_d_green "D, vert"
+    SYletter_d_red "D, rouge"
+    SYnumber_0_blue "0, bleu"
+    SYnumber_0_green "0, vert"
+    SYnumber_0_red "0, rouge"
+    SYnumber_1_blue "1, bleu"
+    SYnumber_1_green "1, vert"
+    SYnumber_1_red "1, rouge"
+    SYnumber_2_blue "2, bleu"
+    SYnumber_2_green "2, vert"
+    SYnumber_2_red "2, rouge"
+    SYnumber_3_blue "3, bleu"
+    SYnumber_3_green "3, vert"
+    SYnumber_3_red "3, rouge"
+    SYnumber_4_blue "4, bleu"
+    SYnumber_4_green "4, vert"
+    SYnumber_4_red "4, rouge"
+    SYnumber_5_blue "5, bleu"
+    SYnumber_5_green "5, vert"
+    SYnumber_5_red "5, rouge"
+    SYnumber_6_blue "6, bleu"
+    SYnumber_6_green "6, vert"
+    SYnumber_6_red "6, rouge"
+    SYnumber_7_blue "7, bleu"
+    SYnumber_7_green "7, vert"
+    SYnumber_7_red "7, rouge"
+    SYnumber_8_blue "8, bleu"
+    SYnumber_8_green "8, vert"
+    SYnumber_8_red "8, rouge"
+    SYnumber_9_blue "9, bleu"
+    SYnumber_9_green "9, vert"
+    SYnumber_9_red "9, red"
+    numberfrom0 "Mise  zro du compteur"
+    items "Elments"
+    syusrmenu "Menu des symboles spcifiques"
+    cfgsymenu "Configuration du menu des symboles spcifiques"
+    insmnb   "Insrer un sous-menu avant"
+    insmna   "Insrer un sous-menu aprs"
+    opensbmn "Ouvrir un sous-menu"
+    clssbmn  "Fermer un sous-menu"
+    duration "Dure"
+    calrs "Calories"
+    optSUPPORTLAPS "Support pour les tapes"
+    LAP  ETP
+    nameLAP "tape"
+    getLAP  "Acquisition des tapes"
+    lapsrun "Course"
 }
 
     # the following definitions must be coherent with $TXT
@@ -1105,5 +1226,6 @@ array set INVTXT {
     WP   WP
     RT   RT
     TR   TR
+    ETP LAP
     GR   GR
 }
