@@ -17,10 +17,10 @@
 #      along with this program.
 #
 #  File		: langid.tcl
-#  Last change	:  20 May 2004
+#  Last change	:  16 October 2004
 #
 # Indonesian language file by Tri Agus Prayitno (acuss@bk.or.id)
-#  last input from him inserted:  12 March 2004
+#  last input from him inserted:  15 July 2004
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -261,6 +261,7 @@ array set MESS {
     cantwrtimg "Gagal membuat file gambar dengan format %s"
     TRsimplres "TR hasil penyederhanaan dibuat dengan nama %s"
     cantsaveRTid "%d RT tidak disimpan: pengidentifikasi bukan angka"
+    cantsaveTRid "%d TR tidak disimpan: pengidentifikasi bukan angka"
     badtrvconf "Konfigurasi rusak; ulangi dengan yang kosong"
     drvsimoff "Simulasi kendara: belum dimulai!"
     needWP "Simulasi kendara: silakan buka atau buat beberapa WP dulu"
@@ -1043,7 +1044,6 @@ array set TXT {
     Ghidden_map_area "Wilayah"
     Ghidden_map_int "Persimpangan"
     Ghidden_map_addr "Alamat"
-    Ghidden_map_label "Label"
     Ghidden_map_line "Garis"
     Ghidden_locked Terkunci
     Ghidden_default "Default"
@@ -1092,6 +1092,13 @@ array set TXT {
     SYpin_red "Pin, merah"
     ozimapfile "File Ozi Map"
     info "Informasi"
+    BGAfeature  "Fitur BGA"
+    BGAfindblty "Ketercarian BGA"
+    BGAairact   "Aktivitas Udara BGA"
+    optUSESLOWOPWINDOW "Jendela untuk kontrol operasi lambat"
+    optDEFTRECPROTOCOL "Protokol default"
+    optLNSREACT "Reaksi LN thd mouse"
+    syhlpbx "Gunakan klik-kanan untuk\nmengubah daftar elemen"
 }
 
     # the following definitions must be coherent with $TXT
