@@ -17,9 +17,9 @@
 #      along with this program.
 #
 #  File: langit.tcl
-#  Last change:  2 June 2004
+#  Last change:  21 October 2004
 #  Italian language file by Alessandro Palmas (alpalmas@tin.it)
-#  last input from him inserted:  2 June 2004
+#  last input from him inserted:  21 October 2004
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -259,6 +259,7 @@ array set MESS {
     cantwrtimg "Errore nella scrittura dell'immagine su file in formato %s"
     TRsimplres "TR risultanti dalla semplificazione creati sotto il nome %s"
     cantsaveRTid "%d RT non salvata/e: identificatore non numerico"
+    cantsaveTRid "%d TR non salvata/e: identificatore non numerico"
     badtrvconf "Configuratione corrotta; ripartire con una vuota"
     drvsimoff "simulatore di guida: non ancora partito!"
     needWP "Simulatore di guida: prego voler caricare o definire alcuni WP"
@@ -270,6 +271,12 @@ array set MESS {
     RTnoWPname "WP in RT indicato dal solo nome non pi supportato"
     distlarge "Distanza eccessiva!"
     timeconsmg "Oprazione che richiede tempo: continuare?"
+    badtimeval "Valore tempo non valido"
+    badLAP "LAP non valido; linea"
+    lapncnsdrd "LAP ignorato"
+    undefinedTR   "TR sconosciuta"
+    emptymenu "Men vuoto; continuo?"
+    cantwrtsymenu "Non posso scrivere il file del men dei simboli"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg {$ALUNIT} stage label"
@@ -973,7 +980,6 @@ array set TXT {
     Ghidden_map_area "Area mappa"
     Ghidden_map_int "Intersezione mappa"
     Ghidden_map_addr "Indirizzo mappa"
-    Ghidden_map_label "Etichetta mappa"
     Ghidden_map_line "Linea mappa"
     Ghidden_locked "Protetto"
     Ghidden_default Default
@@ -1032,6 +1038,127 @@ array set TXT {
     ozimapfile "file Ozi Map"
     info "Informazione"
     climbrate "Velocit ascensionale"
+    BGAfeature "Funzionalit"
+    BGAfindblty "Identificabile semplicamente"
+    BGAairact   "Attivit aerea"
+    optUSESLOWOPWINDOW "Finestra per il controllo di operazioni lente"
+    optDEFTRECPROTOCOL "Protocollo di default"
+    optLNSREACT "LN mappate rispondono al mouse"
+    syhlpbx "Usare il tasto destro del mouse per\nriordinare gli elementi della lista"
+    optDEFMAPPFDATUM "Datum delle coordinate della mappa"
+    mkgrp "Crea Gruppo"
+    dispitems "Oggetti visibili"
+    hiditems "Oggetti nascosti"
+    optAutoNumRts "Numerare automaticamente le RT in uscita"
+    Ghidden_transparent Transparente
+    Ghidden_temp Temperatura
+    Ghidden_time "Time stamp"
+    Ghidden_cat Categoria
+    SYopen_24hr "Aperto 24 ore"
+    SYfhs_facility "Attrezzature FHS"
+    SYbot_cond "Condizioni del fondo"
+    SYtide_pred_stn "Stazione previsione marea/correnti"
+    SYanchor_prohib "Divieto d'ancoraggio"
+    SYbeacon "Segno"
+    SYcoast_guard "Guardia Costiera"
+    SYreef "Secca"
+    SYweedbed "Banco d'alghe"
+    SYdropoff "Ingresso"
+    SYdock "Dock"
+    SYmarina "Porticciolo"
+    SYbait_tackle "Esche ed attrezzatura da pesca"
+    SYstump "Ceppo"
+    SYcntct_smiley "Smiley"
+    SYcntct_ball_cap "Berretto da baseball"
+    SYcntct_big_ears "Grande orecchio"
+    SYcntct_spike "Punta"
+    SYcntct_goatee "Pizzetto"
+    SYcntct_afro "Cespuglio"
+    SYcntct_dreads "Treccine"
+    SYcntct_female1 "Femminile 1"
+    SYcntct_female2 "Femminile 2"
+    SYcntct_female3 "Femminile 3"
+    SYcntct_ranger "Ranger"
+    SYcntct_kung_fu "Kung fu"
+    SYcntct_sumo "Sumo"
+    SYcntct_pirate "Pirata"
+    SYcntct_biker "Ciclista"
+    SYcntct_alien "Alieno"
+    SYcntct_bug "Insetto"
+    SYcntct_cat "Gatto"
+    SYcntct_dog "Cane"
+    SYcntct_pig "Maiale"
+    SYhydrant "Idrante Antincendio"
+    SYcircle_blue "Cerchio blu"
+    SYcircle_green "Cerchio verde"
+    SYcircle_red "Cerchio rosso"
+    SYdiamond_blue "Rombo blu"
+    SYoval_blue "Ovale blu"
+    SYoval_green "Ovale verde"
+    SYoval_red "Ovale rosso"
+    SYrect_blue "Cubo blu"
+    SYrect_green "Cubo verde"
+    SYrect_red "Cubo rosso"
+    SYsquare_blue "Quadrato blu"
+    SYtriangle_blue "Triangolo blu"
+    SYtriangle_green "Triangolo verde"
+    SYtriangle_red "Triangolo rosso"
+    SYletter_a_blue "A blu"
+    SYletter_a_green "A verde"
+    SYletter_a_red "A rosso"
+    SYletter_b_blue "B blu"
+    SYletter_b_green "B verde"
+    SYletter_b_red "B rosso"
+    SYletter_c_blue "C blu"
+    SYletter_c_green "C verde"
+    SYletter_c_red "C rosso"
+    SYletter_d_blue "D blu"
+    SYletter_d_green "D verde"
+    SYletter_d_red "D rosso"
+    SYnumber_0_blue "0 blu"
+    SYnumber_0_green "0 verde"
+    SYnumber_0_red "0 rosso"
+    SYnumber_1_blue "1 blu"
+    SYnumber_1_green "1 verde"
+    SYnumber_1_red "1 rosso"
+    SYnumber_2_blue "2 blu"
+    SYnumber_2_green "2 verde"
+    SYnumber_2_red "2 rosso"
+    SYnumber_3_blue "3 blu"
+    SYnumber_3_green "3 verde"
+    SYnumber_3_red "3 rosso"
+    SYnumber_4_blue "4 blu"
+    SYnumber_4_green "4 verde"
+    SYnumber_4_red "4 rosso"
+    SYnumber_5_blue "5 blu"
+    SYnumber_5_green "5 verde"
+    SYnumber_5_red "5 rosso"
+    SYnumber_6_blue "6 blu"
+    SYnumber_6_green "6 verde"
+    SYnumber_6_red "6 rosso"
+    SYnumber_7_blue "7 blu"
+    SYnumber_7_green "7 verde"
+    SYnumber_7_red "7 rosso"
+    SYnumber_8_blue "8 blu"
+    SYnumber_8_green "8 verde"
+    SYnumber_8_red "8 rosso"
+    SYnumber_9_blue "9 blu"
+    SYnumber_9_green "9 verde"
+    SYnumber_9_red "9 rosso"
+    numberfrom0 "Poni contatore a 1"
+    items "Oggetti"
+    syusrmenu "Men utente simboli"
+    cfgsymenu "Configura men utente simboli"
+    insmnb   "Inserisci sub-men prima"
+    insmna   "Inserisci sub-men dopo"
+    opensbmn "Apri sub-men"
+    clssbmn  "Chiudi sub-men"
+    optSUPPORTLAPS "Supporto giri"
+    LAP  GIRO
+    nameLAP "Giro"
+    duration "Tempo"
+    calrs "Calorie"
+    getLAP  "Ricezione giri in corso"
 }
 
     # the following definitions must be coherent with $TXT
@@ -1044,6 +1171,7 @@ array set INVTXT {
     WP   WP
     RT   RT
     TR   TR
+    GIRO LAP
     GR   GR
 }
 
