@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: langnl.tcl
-#  Last change:  22 October 2004
+#  Last change:  26 October 2004
 #  Dutch language file by Rob Buitenhuis (rob@buitenhs.demon.nl)
 #  last input from him inserted: 22 October 2004
 #
@@ -1190,7 +1190,7 @@ array set TXT {
     duration "Duur"
     calrs "Calorieen"
     getLAP  "Ophalen rondes"
-    run "Wedstrijd"
+    lapsrun "Wedstrijd"
 }
 
     # the following definitions must be coherent with $TXT
