@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: langport.tcl
-#  Last change:  31 May 2004
+#  Last change:  22 October 2004
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -127,6 +127,7 @@ array set MESS {
     getWP   "A buscar Pontos"
     getRT   "A buscar Rotas"
     getTR   "A buscar Trajectos"
+    getLAP  "A buscar Voltas"
     putWP   "A pr Pontos"
     putRT   "A pr Rotas"
     putTR   "A pr Trajectos"
@@ -262,6 +263,7 @@ array set MESS {
     unobscmap "Erro talvez por haver 1 janela/cone sobre o mapa; esperar e voltar a tentar?"
     cantwrtimg "Erro ao guardar imagem em ficheiro no formato %s"
     cantsaveRTid "%d RT(s) por salvar: identificador no numrico"
+    cantsaveTRid "%d TR(s) por salvar: identificador no numrico"
     badtrvconf "Configurao inconsistente substituda por uma vazia"
     drvsimoff "Simulador de conduo: falta iniciar!"
     needWP "Simulador de conduo:  preciso definir ou ler PTs"
@@ -277,6 +279,12 @@ array set MESS {
     badconv "Erro na converso do parmetro %s: %s"
     badprmval "Resultado errado da converso do parmetro %s: %s"
     timeconsmg "Operao lenta: continuar?"
+    badtimeval "Valor de tempo errado"
+    badLAP "VLT errada; linha"
+    lapncnsdrd "VLT ignorada"
+    undefinedTR "TR no existente"
+    emptymenu "Menu vazio; continuar?"
+    cantwrtsymenu "No posso escrever no ficheiro do menu de smbolos"
 }
 
 set TXT(RTcompflds) "# PT {$DTUNIT} grau {$ALUNIT} etapa etiq"
@@ -425,6 +433,9 @@ array set TXT {
     optTRNUMBERINTVL "Mostrar nmero de PT de TR cada"
     opt_Formats   "Unidades e formatos"
     optDISTUNIT   "Distncia"
+    optUSESLOWOPWINDOW "Janela de controle de operaes lentas"
+    optDEFTRECPROTOCOL "Protocolo habitual"
+    optLNSREACT "LNs no mapa reagem ao rato"
     KM    km
     NAUTMILE    "milha nutica"
     STATMILE    "milha terrestre"
@@ -525,6 +536,7 @@ array set TXT {
     RT   RT
     TR   TR
     GR   GR
+    LAP  VLT
     commrec   "Comunicao com receptor"
     abort   Desistir
     ACKs   ACKs
@@ -544,43 +556,48 @@ array set TXT {
     mpbkgrcs "Posio na grelha"
     nameImage Imagem
     symbol Smbolo
+    SY1st_aid "Primeiros socorros"
+    SYCATaviation Aviao
     SYCATgeneral Genrico
     SYCATland Terrestre
     SYCATwater Aqutico
-    SYCATaviation Aviao
-    SY1st_aid "Primeiros socorros"
-    SYWP_buoy_white "Bia, branca"
+    SYMOB "Homem ao mar"
+    SYWP_buoy_white "Bia branca"
     SYWP_dot "Ponto"
     SYairport "Aeroporto"
     SYamusement_park "Parque de diverses"
     SYanchor "ncora"
+    SYanchor_prohib "ncora proibida"
     SYavn_danger "Perigo (av)"
+    SYbait_tackle "Isco e equipamento"
     SYball "Bola"
     SYbeach "Praia"
+    SYbeacon "Balisa"
     SYbell "Sino"
     SYbiker "Ciclista"
     SYboat "Barco"
     SYboat_ramp "Rampa p/ barcos"
     SYborder "Fronteira"
-    SYbox_blue "Caixa, azul"
-    SYbox_green "Caixa, verde"
-    SYbox_red "Caixa, vermelha"
+    SYbot_cond "Condies de fundo"
+    SYbox_blue "Caixa azul"
+    SYbox_green "Caixa verde"
+    SYbox_red "Caixa vermelha"
     SYbridge "Ponte"
     SYbuilding "Prdio"
-    SYbuoy_amber "Bia, mbar"
-    SYbuoy_black "Bia, preta"
-    SYbuoy_blue "Bia, azul"
-    SYbuoy_green "Bia, verde"
-    SYbuoy_green_red "Bia, verde vermelha"
-    SYbuoy_green_white "Bia, verde branca"
-    SYbuoy_orange "Bia, laranja"
-    SYbuoy_red "Bia, vermelha"
-    SYbuoy_red_green "Bia, vermelha verde"
-    SYbuoy_red_white "Bia, vermelha branca"
-    SYbuoy_violet "Bia, violeta"
-    SYbuoy_white "Bia, branca"
-    SYbuoy_white_green "Bia, branca verde"
-    SYbuoy_white_red "Bia, branca vermelha"
+    SYbuoy_amber "Bia mbar"
+    SYbuoy_black "Bia preta"
+    SYbuoy_blue "Bia azul"
+    SYbuoy_green "Bia verde"
+    SYbuoy_green_red "Bia verde vermelha"
+    SYbuoy_green_white "Bia verde branca"
+    SYbuoy_orange "Bia laranja"
+    SYbuoy_red "Bia vermelha"
+    SYbuoy_red_green "Bia vermelha verde"
+    SYbuoy_red_white "Bia vermelha branca"
+    SYbuoy_violet "Bia violeta"
+    SYbuoy_white "Bia branca"
+    SYbuoy_white_green "Bia branca verde"
+    SYbuoy_white_red "Bia branca vermelha"
     SYcamping "Campismo"
     SYcapitol_city "Cidade, estrela"
     SYcar "Automvel"
@@ -591,43 +608,72 @@ array set TXT {
     SYcemetery "Cemitrio"
     SYchapel "Capela"
     SYchurch "Igreja"
+    SYcircle_blue "Crculo azul"
+    SYcircle_green "Crculo verde"
+    SYcircle_red "Crculo vermelho"
     SYcircle_x "Crculo com X"
     SYcivil "Instalaes civis"
+    SYcntct_afro "Lzudo"
+    SYcntct_alien "Extra-terrestre"
+    SYcntct_ball_cap "Bon"
+    SYcntct_big_ears "Orelhudo"
+    SYcntct_biker "Ciclista"
+    SYcntct_bug "Carrapato"
+    SYcntct_cat "Gato"
+    SYcntct_dog "Co"
+    SYcntct_dreads "Tranas"
+    SYcntct_female1 "Mulher 1"
+    SYcntct_female2 "Mulher 2"
+    SYcntct_female3 "Mulher 3"
+    SYcntct_goatee "Pras"
+    SYcntct_kung_fu "Kung fu"
+    SYcntct_pig "Porco"
+    SYcntct_pirate "Pirata"
+    SYcntct_ranger "Ranger"
+    SYcntct_smiley "Sorriso"
+    SYcntct_spike "Espeto"
+    SYcntct_sumo "Sumo"
+    SYcoast_guard "Guarda costeira"
     SYcrossing "Passadeira"
     SYdam "Barragem"
     SYdanger "Perigo"
     SYdeer "Veado"
-    SYdiamond_green "Losango, verde"
-    SYdiamond_red "Losango, vermelho"
-    SYdiver_down_2 "Mergulhador 2"
+    SYdiamond_blue "Losango azul"
+    SYdiamond_green "Losango verde"
+    SYdiamond_red "Losango vermelho"
     SYdiver_down_1 "Mergulhador 1"
+    SYdiver_down_2 "Mergulhador 2"
+    SYdock "Doca"
     SYdollar "Dolar"
     SYdot "Ponto"
     SYdrinking_water "gua potvel"
+    SYdropoff "Entrada"
     SYduck "Pato"
     SYelevation "Ponto alto"
     SYexit "Sada"
     SYexit_no_serv "Sada s/ servios"
     SYfactory "Fbrica"
+    SYfhs_facility "Instalao FHS"
     SYfish "Peixe"
     SYfitness "Ginstica"
     SYflag "Bandeira"
-    SYflag_pin_blue "Mastro, azul"
-    SYflag_pin_green "Mastro, verde"
-    SYflag_pin_red "Mastro, vermelho"
+    SYflag_pin_blue "Mastro azul"
+    SYflag_pin_green "Mastro verde"
+    SYflag_pin_red "Mastro vermelho"
     SYfreeway "Via rpida"
     SYfuel "Gasolina"
     SYfuel_store "Gasolina & loja"
-    SYgeocache "Geocache"
-    SYgeocache_fnd "Geocache descoberta"
     SYgeo_name_land "Nome geogr, terra"
     SYgeo_name_man "Nome geogr, homem"
     SYgeo_name_water "Nome geogr, gua"
+    SYgeocache "Geocache"
+    SYgeocache_fnd "Geocache descoberta"
     SYglider "Asa delta"
     SYheliport "Heliporto"
     SYhorn "Buzina"
     SYhouse "Casa"
     SYhouse_2 "Casa 2"
+    SYhydrant "Boca de incndio"
     SYice_skating "Patinagem no gelo"
     SYinfo "Informao"
     SYintersection "Interseco"
@@ -635,20 +681,31 @@ array set TXT {
     SYknife_fork "Comida"
     SYladder "Escada"
     SYlanding "Aterragem"
-    SYlarge_city "Cidade, grande"
+    SYlarge_city "Cidade grande"
     SYlarge_exit_ns "Sada s/ serv, grande"
     SYlarge_ramp_int "Cruz rampas, grande"
+    SYletter_a_blue "A azul"
+    SYletter_a_green "A verde"
+    SYletter_a_red "A vermelho"
+    SYletter_b_blue "B azul"
+    SYletter_b_green "B verde"
+    SYletter_b_red "B vermelho"
+    SYletter_c_blue "C azul"
+    SYletter_c_green "C verde"
+    SYletter_c_red "C vermelho"
+    SYletter_d_blue "D azul"
+    SYletter_d_green "D verde"
+    SYletter_d_red "D vermelho"
     SYlevee "Dique"
     SYlight "Farol"
     SYlodging "Alojamento"
     SYmany_fish "Cardume"
     SYmany_tracks "Muitos caminhos"
     SYmark_x "Marca, x"
-    SYmedium_city "Cidade, mdia"
+    SYmedium_city "Cidade mdia"
     SYmile_marker "Marco"
     SYmilitary "Instalaes militares"
     SYmine Mina
-    SYMOB "Homem ao mar"
     SYmonument "Monumento"
     SYmountains "Montanhas"
     SYmovie "Cinema"
@@ -657,54 +714,99 @@ array set TXT {
     SYntl_highway "Auto-estrada nacional"
     SYnull "(transparente)"
     SYnull_2 "(vazio)"
+    SYnumber_0_blue "0 azul"
+    SYnumber_0_green "0 verde"
+    SYnumber_0_red "0 vermelho"
+    SYnumber_1_blue "1 azul"
+    SYnumber_1_green "1 verde"
+    SYnumber_1_red "1 vermelho"
+    SYnumber_2_blue "2 azul"
+    SYnumber_2_green "2 verde"
+    SYnumber_2_red "2 vermelho"
+    SYnumber_3_blue "3 azul"
+    SYnumber_3_green "3 verde"
+    SYnumber_3_red "3 vermelho"
+    SYnumber_4_blue "4 azul"
+    SYnumber_4_green "4 verde"
+    SYnumber_4_red "4 vermelho"
+    SYnumber_5_blue "5 azul"
+    SYnumber_5_green "5 verde"
+    SYnumber_5_red "5 vermelho"
+    SYnumber_6_blue "6 azul"
+    SYnumber_6_green "6 verde"
+    SYnumber_6_red "6 vermelho"
+    SYnumber_7_blue "7 azul"
+    SYnumber_7_green "7 verde"
+    SYnumber_7_red "7 vermelho"
+    SYnumber_8_blue "8 azul"
+    SYnumber_8_green "8 verde"
+    SYnumber_8_red "8 vermelho"
+    SYnumber_9_blue "9 azul"
+    SYnumber_9_green "9 verde"
+    SYnumber_9_red "9 vermelho"
     SYoil_field "Campo de petrleo"
+    SYopen_24hr "Aberto 24 horas"
+    SYoval_blue "Oval azul"
+    SYoval_green "Oval verde"
+    SYoval_red "Oval vermelha"
     SYparachute "Paraquedas"
     SYpark "Parque"
     SYparking "Aparcamento"
     SYpharmacy "Farmcia"
     SYphone "Telefone"
     SYpicnic "Picnic"
-    SYpin_blue "Alfinete, azul"
-    SYpin_green "Alfinete, verde"
-    SYpin_red "Alfinete, vermelho"
+    SYpin_blue "Alfinete azul"
+    SYpin_green "Alfinete verde"
+    SYpin_red "Alfinete vermelho"
     SYpolice "Polcia"
     SYpost_office "Correios"
     SYprivate "Campo privado"
     SYradio_beacon "Rdio farol"
     SYramp_int "Cruza/o rampas" 
+    SYrect_blue "Oval azul"
+    SYrect_green "Oval verde"
+    SYrect_red "Oval vermelha"
+    SYreef "Recife"
     SYrestrooms "WC"
     SYscenic "Panorama"
     SYschool "Escola"
     SYseaplane "Base de hidro-avies"
     SYshopping_cart "Centro comercial"
-    SYshort_tower "Torre, baixa"
+    SYshort_tower "Torre baixa"
     SYshowers "Chuveiros"
     SYskiing "Ski aqutico"
     SYskull "Caveira"
-    SYsmall_city "Cidade, pequena"
+    SYsmall_city "Cidade pequena"
     SYsnow_skiing "Ski de neve"
     SYsoft_field "Campo mole"
-    SYsquare_green "Quadrado, verde"
-    SYsquare_red "Quadrado, vermelho"
+    SYsquare_blue "Quadrado azul"
+    SYsquare_green "Quadrado verde"
+    SYsquare_red "Quadrado vermelho"
     SYst_highway "Auto-estrada estadual"
     SYstadium "Estdio"
     SYstore "Loja"
     SYstreet_int "Cruza/o ruas"
+    SYstump "Escolho"
     SYsummit "Pico"
     SYswimming "Natao"
     SYtake_off "Descolagem"
-    SYtall_tower "Torre, alta"
+    SYtall_tower "Torre alta"
     SYtheater Teatro
+    SYtide_pred_stn Margrafo
     SYtoll Portagem
     SYtow_truck "Pronto-socorro"
     SYtraceback "Regresso"
     SYtracks "Caminhos"
     SYtrail_head "Incio de caminho"
     SYtree "rvore"
+    SYtriangle_blue "Tringulo azul"
+    SYtriangle_green "Tringulo verde"
+    SYtriangle_red "Tringulo vermelho"
     SYtruck_stop "Paragem"
     SYtunnel "Tnel"
     SYultralight "Ultra-ligeiro"
     SYus_highway "Auto-estrada EUA"
+    SYweedbed "Algas"
     SYweight_station Bscula
     SYwreck "Destroos"
     SYzoo "Jardim zoolgico"
@@ -1020,7 +1122,6 @@ array set TXT {
     Ghidden_map_area "rea (mapa)"
     Ghidden_map_int "Interseco (mapa)"
     Ghidden_map_addr "Endereo (mapa)"
-    Ghidden_map_label "Etiqueta (mapa)"
     Ghidden_map_line "Linha (mapa)"
     Ghidden_locked Bloqueado
     Ghidden_default "Normal"
@@ -1045,10 +1146,15 @@ array set TXT {
     Ghidden_net Rede
     Ghidden_direct Directo
     Ghidden_snap Colado
+    Ghidden_transparent Transparente
+    Ghidden_temp Temperatura
+    Ghidden_time "Tempo"
+    Ghidden_cat Categoria
     renres "NOVOS NOMES"
     forgetGRcs "Esquecer GR&Els"
     optDEFMAPPROJ "Projeco do mapa"
     optDEFMAPPFRMT "Coordenadas no mapa"
+    optDEFMAPPFDATUM "Datum p/ coords no mapa"
     undo Desfazer
     UTMzone zona
     tfwfile  "ficheiro TFW"
@@ -1076,8 +1182,28 @@ array set TXT {
     errwarn "Erro/aviso(s)!"
     changegroupsymbol "Mudar smbolo"
     ozimapfile "ficheiro Ozi Map"
-    info "Informao""
+    info "Informao"
     climbrate "Taxa de subida"
+    BGAfeature  "Local"
+    BGAfindblty "Facilidade de identificar"
+    BGAairact   "Actividade area"
+    dispitems "Items no mapa"
+    hiditems "Items no no mapa"
+    mkgrp "Criar Grupo"
+    optAutoNumRts "Renumerar RTs ao colocar"
+    optSUPPORTLAPS "Suportar voltas"
+    numberfrom0 "Numerador a 1"
+    nameLAP "Volta"
+    duration "Durao"
+    calrs "Calorias"
+    syusrmenu "Alterar menu de smbolos"
+    cfgsymenu "Configurar menu de smbolos"
+    insmnb   "Inserir sub-menu antes"
+    insmna   "Inserir sub-menu depois"
+    opensbmn "Abrir sub-menu"
+    clssbmn  "Fechar sub-menu"
+    syhlpbx "Usar boto direito para\nreordenar elementos da lista"
+    lapsrun Corrida
 }
 
     # the following definitions must be coherent with $TXT
@@ -1090,6 +1216,7 @@ array set INVTXT {
     PT   WP
     RT   RT
     TR   TR
+    VLT  LAP
     GR   GR
     p   FT
 }
