@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: magellan.tcl
-#  Last change:  17 September 2004
+#  Last change:  22 November 2004
 #
 # This file contributed by Matt Martin (matt.martin@ieee.org)
 #  Copyright (c) 2003 Matt Martin (matt.martin@ieee.org)
@@ -1298,7 +1298,7 @@ proc ConvWPData {data} {
 			     $PositionFormat "" DDD] {
 			    break
 		    }
-		    set all [lreplace $all 0 1 $datum $pfmt]
+		    set vs [lreplace $vs 0 1 $datum $pfmt]
 		}
 		Symbol {
 		    #set v 1st_aid
