@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: navigate.tcl
-#  Last change:  30 October 2003
+#  Last change:  16 September 2004
 #
 
 ##### travel/navigation display
@@ -61,6 +61,8 @@ proc TravelInit {fr} {
     $mn add separator
     $mn add command -label $TXT(navMOB) -foreground $COLOUR(check) \
 	    -command { TravelNav MOB }
+    $mn add command -label "$TXT(create) $TXT(WP)" \
+	    -command { TravelMarkPoint }
     $mn add cascade -label $TXT(startnav) -menu $mn.ms
     menu $mn.ms
     $mn.ms add command -label $TXT(navWP) -command { TravelNav WP }
@@ -122,13 +124,13 @@ proc TravelInit {fr} {
 
     foreach dsp $Travel(displays) {
 	radiobutton $fr.fctrl.b$dsp -value $dsp -anchor w \
-		-selectcolor $COLOUR(check) \
+		-selectcolor $COLOUR(check) -variable Travel(travel,cdsp,b) \
 		-command "TravelChangeDisplay $dsp $fr.fri"
 	BalloonBindings $fr.fctrl.b$dsp \
 		[list "=[format $TXT(travchgdisplay) $dsp]"]
 	grid $fr.fctrl.b$dsp -row 1 -column [expr $dsp-1]
     }
-    $fr.fctrl.b$Travel(travel,cdsp) select
+    set Travel(travel,cdsp,b) $Travel(travel,cdsp)
     frame $fr.fri
     set Travel(travel,dsppfr) $fr.fri
     foreach dsp $Travel(displays) {
@@ -786,8 +788,8 @@ proc TravelWCAction {act args} {
 		    set ix $Travel(wcfg-int,$e,wpix)
 		    set p $WPPosn($ix)
 		    if { $WPDatum($ix) != $Travel(nav,datum) } {
-			set p [ConvertDatum [lindex $p 0] [lindex $p 1] \
-				$WPDatum($ix) $Travel(nav,datum) DDD]
+			set p [ToDatum [lindex $p 0] [lindex $p 1] \
+				$WPDatum($ix) $Travel(nav,datum)]
 		    }
 		    set Travel(warn,$e,pos) $p
 		}
@@ -888,8 +890,8 @@ proc TravelNavToWP {ix} {
 
     set p $WPPosn($ix)
     if { $WPDatum($ix) != $Travel(nav,datum) } {
-	set p [ConvertDatum [lindex $p 0] [lindex $p 1] \
-		$WPDatum($ix) $Travel(nav,datum) DDD]
+	set p [ToDatum [lindex $p 0] [lindex $p 1] \
+		   $WPDatum($ix) $Travel(nav,datum)]
     }
     set Travel(nav,nxtgoal) $p
     set Travel(nav,afternxt) ""
@@ -905,8 +907,8 @@ proc TravelNavToMOB {} {
     global Travel RealTimeLogAnim
 
     # create MOB WP
-    set p [CreatePos [lindex $Travel(prevposn) 0] \
-	    [lindex $Travel(prevposn) 1] DDD $Travel(nav,datum)]
+    set p [FormatLatLong [lindex $Travel(prevposn) 0] \
+	       [lindex $Travel(prevposn) 1] DDD]
     set n [NewName WP MOB]
     set d [FormData WP "Name Commt Posn PFrmt Datum Symbol Obs" \
 	    [list $n MOB $p DDD $Travel(nav,datum) MOB "MOB\n[NowTZ]"]]
@@ -917,6 +919,31 @@ proc TravelNavToMOB {} {
     return
 }
 
+proc TravelMarkPoint {} {
+    # create waypoint at current log position
+    global Travel RealTimeLogAnim TXT CREATIONDATE
+
+    if { [set secs $Travel(prevtime)] == -1 } {
+	TravelDoWarn $TXT(trvwnopos) info
+	return
+    }
+    set p [FormatLatLong [lindex $Travel(prevposn) 0] \
+	       [lindex $Travel(prevposn) 1] DDD]
+    set opts [list create revert cancel]
+    set dt [DateFromSecs $secs]
+    if { $CREATIONDATE } {
+	GMWPoint -1 $opts \
+	    [FormData WP "PFrmt Posn Datum Date Displ" \
+		 [list DDD $p $Travel(nav,datum) $dt $RealTimeLogAnim]]
+    } else {
+	GMWPoint -1 $opts \
+	    [FormData WP "Commt PFrmt Posn Datum Displ" \
+		 [list [DateCommt $dt] DDD $p $Travel(nav,datum) \
+		     $RealTimeLogAnim]]
+    }
+    return
+}
+
 proc TravelNavToRT {ix} {
     # start navigation to RT with given index
     # return 0 on failure
@@ -930,8 +957,8 @@ proc TravelNavToRT {ix} {
 	}
 	set p $WPPosn($wpix)
 	if { $WPDatum($wpix) != $Travel(nav,datum) } {
-	    set p [ConvertDatum [lindex $p 0] [lindex $p 1] \
-		    $WPDatum($wpix) $Travel(nav,datum) DDD]
+	    set p [ToDatum [lindex $p 0] [lindex $p 1] \
+		       $WPDatum($wpix) $Travel(nav,datum)]
 	}
 	lappend ps $p
 	lappend wpixs $wpix
