@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: options.tcl
-#  Last change:  18 January 2004
+#  Last change:  12 September 2004
 #
 
 # when inserting new data here, define TXT(opt*)
@@ -76,8 +76,8 @@ set OPTSTRUCT {   GPSREC _GPSRecConf _Formats _sep
 }
 
 set OPTTYPE(_Interf) group
-set OPTGRPL(_Interf) {MWINDOWSCONF LANG ISOLATIN1 DELETE BalloonHelp
-                      TRNUMBERINTVL}
+set OPTGRPL(_Interf) {MWINDOWSCONF LANG ISOLATIN1 DELETE USESLOWOPWINDOW
+                      BalloonHelp TRNUMBERINTVL LNSREACT}
 set OPTTYPE(MWINDOWSCONF) fixedtextmenu
 set OPTMENUCONTS(MWINDOWSCONF) {map lists}
 set OPTMENUNAMES(MWINDOWSCONF) TXT
@@ -88,35 +88,17 @@ set OPTMENUNAMES(LANG) TXT
 set OPTMENUPREFIX(LANG) LANG
 set OPTTYPE(ISOLATIN1) boolean
 set OPTTYPE(DELETE) boolean
+set OPTTYPE(USESLOWOPWINDOW) boolean
 set OPTTYPE(BalloonHelp) boolean
 set OPTTYPE(TRNUMBERINTVL) nat
+set OPTTYPE(LNSREACT) boolean
 
 set OPTTYPE(GPSREC) menu
 set OPTMENUPROC(GPSREC) FillRecModelsMenu
 
-# the _GPSRecConf description may be changed by proc RecModelChange
-#  in file recmodels.tcl when $GPSREC changes
-set OPTTYPE(_GPSRecConf) group
-set OPTGRPL(_GPSRecConf) {ACCEPTALLCHARS NAMELENGTH COMMENTLENGTH MAXWPOINTS
-                      MAXROUTES MAXWPINROUTE MAXTPOINTS CREATIONDATE
-                      NOLOWERCASE DEFAULTSYMBOL DEFAULTDISPOPT}
-set OPTTYPE(ACCEPTALLCHARS) boolean
-set OPTTYPE(NAMELENGTH) nat
-set OPTTYPE(COMMENTLENGTH) nat
-set OPTTYPE(MAXWPOINTS) nat
-set OPTTYPE(MAXROUTES) nat
-set OPTTYPE(MAXWPINROUTE) nat
-set OPTTYPE(MAXTPOINTS) nat
-set OPTTYPE(CREATIONDATE) boolean
-set OPTTYPE(NOLOWERCASE) boolean
-set OPTTYPE(DEFAULTSYMBOL) textmenu
-set OPTMENUPROC(DEFAULTSYMBOL) FillSymbolsMenu
-set OPTMENUNAMES(DEFAULTSYMBOL) TXT
-set OPTMENUPREFIX(DEFAULTSYMBOL) SY
-set OPTTYPE(DEFAULTDISPOPT) fixedtextmenu
-set OPTMENUCONTS(DEFAULTDISPOPT) $DISPOPTS
-set OPTMENUNAMES(DEFAULTDISPOPT) TXT
-set OPTMENUPREFIX(DEFAULTDISPOPT) DISP
+# the _GPSRecConf description is defined by proc RecModelChange
+#  in file recmodels.tcl on start up and when $GPSREC changes
+# set OPTTYPE(_GPSRecConf) group
 
 set OPTTYPE(_Data) group
 set OPTGRPL(_Data) {EQNAMEDATA KEEPHIDDEN}
@@ -129,8 +111,8 @@ set OPTVALS(KEEPHIDDEN) {never ask always}
 
 set OPTTYPE(_Formats) group
 set OPTGRPL(_Formats) {Datum TimeOffset DISTUNIT ALTUNIT PositionFormat
-                       DateFormat DEFMAPPROJ DEFMAPPFRMT ACCFORMULAE
-                       ASKPROJPARAMS}
+                       DateFormat DEFMAPPROJ DEFMAPPFRMT DEFMAPPFDATUM
+                       ACCFORMULAE ASKPROJPARAMS}
 
 set OPTTYPE(Datum) menu
 set OPTMENUPROC(Datum) FillDatumMenu
@@ -159,6 +141,9 @@ set OPTMENUPREFIX(DEFMAPPROJ) PRJ
 set OPTTYPE(DEFMAPPFRMT) fixedmenu
 set OPTMENUCONTS(DEFMAPPFRMT) $PFORMATS
 
+set OPTTYPE(DEFMAPPFDATUM) menu
+set OPTMENUPROC(DEFMAPPFDATUM) FillDatumMenu
+
 set OPTTYPE(ACCFORMULAE) boolean
 
 set OPTTYPE(ASKPROJPARAMS) boolean
