@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: posncomp.tcl
-#  Last change:  25 May 2004
+#  Last change:  16 September 2004
 #
 
 ## algorithms and formulae taken or adapted from
@@ -34,9 +34,10 @@
 #      Peter H. Dana, University of Texas
 ##
 
-proc ConvertDatum {latd longd datum0 datum1 pformt} {
+proc ToDatum {latd longd datum0 datum1} {
     # convert position given in lat/long signed degrees from one datum
-    #  to another, and yield position in format $pformt
+    #  to another
+    # return list with lat and long in signed degrees
 
     if { $datum0 != $datum1 } {
 	set phi [expr $latd*0.01745329251994329576]
@@ -85,7 +86,7 @@ proc ConvertDatum {latd longd datum0 datum1 pformt} {
     } else {
 	set clat $latd ; set clong $longd
     }
-    return [CreatePos $clat $clong $pformt $datum1]
+    return [list $clat $clong]
 }
 
        # reference TM lat
