@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: realtime.tcl
-#  Last change:  28 April 2004
+#  Last change:  7 October 2004
 #
 
 #### real time logging control
@@ -169,7 +169,7 @@ proc UseRealTimeData {data} {
     foreach "epe eph epv" $err {}
     foreach "velx vely velz" $velv {}
     if { $RealTimeLogAnim } { AnimNextRealTime $rpos "WGS 84" $secs }
-    set posn [eval CreatePos $rpos DMS [list {WGS 84}]]
+    set posn [eval FormatLatLong $rpos DMS]
     set flat [lindex $posn 2] ; set flong [lindex $posn 3]
     if { $Travelling } {
 	TravelData [lrange $date 3 5] $posn $flat $flong $fix $alt \
@@ -182,19 +182,18 @@ proc UseRealTimeData {data} {
     set PVTElapsed "    [FormatTime [expr $secs-$PVTZero]]"
     lappend PVTSecs $secs
     lappend PVTPosns $posn
-    set pe [lindex $data 3] ; set v [lindex $data 5]
     set vals [list [format "%4d." [incr PVTLast]] \
 	    [eval FormatDate $DateFormat $date] \
 	    $flat $flong \
-	    [RTimeFormat [lindex $data 4] %7.1f] \
-	    $TXT(posfix[lindex $data 2]) \
-	    [RTimeFormat [lindex $pe 0] %5.1f] \
-	    [RTimeFormat [lindex $pe 1] %5.1f] \
-	    [RTimeFormat [lindex $pe 2] %5.1f] \
-	    [RTimeFormat [lindex $v 0] %7.1f] \
-	    [RTimeFormat [lindex $v 1] %7.1f] \
-	    [RTimeFormat [lindex $v 2] %7.1f] \
-	    [RTimeFormat [lindex $data 6] %3.1f]]
+	    [RTimeFormat $alt %7.1f] \
+	    $TXT(posfix$fix) \
+	    [RTimeFormat $epe %5.1f] \
+	    [RTimeFormat $eph %5.1f] \
+	    [RTimeFormat $epv %5.1f] \
+	    [RTimeFormat $velx %7.1f] \
+	    [RTimeFormat $vely %7.1f] \
+	    [RTimeFormat $velz %7.1f] \
+	    [RTimeFormat $trk %3.1f]]
     if { $PVTDFile != "" } { RTimeDumpLine $vals }
 
     if { ! $CMDLINE } {
@@ -450,9 +449,15 @@ proc RTimeDump {} {
 }
 
 proc RTimeDumpLine {vals} {
-    # dump PVT data (except line number)
-    global PVTDFile
+    # dump PVT data (except line number) unless only one fix is to be
+    #  got (in command-line mode) in which case set the appropriate
+    #  global to the PVT data
+    global PVTDFile RealTimeGettingFix
 
+    if { $RealTimeGettingFix != 0 } {
+	if { $RealTimeGettingFix == 1 } { set RealTimeGettingFix $vals }
+	return
+    }
     set sep ""
     foreach v [lreplace $vals 0 0] {
 	puts -nonewline $PVTDFile "${sep}$v"
@@ -615,10 +620,9 @@ proc SimulDriveStart {} {
     set ix [lindex $ix 0]
     set p $WPPosn($ix)
     if { $WPDatum($ix) != "WGS 84" } {
-	set p [ConvertDatum [lindex $p 0] [lindex $p 1] \
-		$WPDatum($ix) "WGS 84" DDD]
-    }
-    set p [lrange $p 0 1]
+	set p [ToDatum [lindex $p 0] [lindex $p 1] \
+		   $WPDatum($ix) "WGS 84"]
+    } else { set p [lrange $p 0 1] }
     foreach x "trk turn speed" { set SimulDrive($x) 0 }
     TurnObject 0 $SimulDrive(wheel)
     set SimulDrive(secs) [clock seconds]
