@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: recdefs.tcl
-#  Last change:  12 October 2003
+#  Last change:  3 October 2004
 #
 # Includes contributions by Matt Martin (matt.martin@ieee.org)
 #  marked "MGM contribution"
@@ -25,12 +25,6 @@
 
 # general definitions that may depend on the receiver trade-mark
 
-  # assuming trade mark is the first list element in $GPSREC
-set MYGPS [lindex $GPSREC 0]
-set MYGPSMODEL [lreplace $GPSREC 0 0]
-
-RecModelChange $MYGPS
-
 set TYPES {WP RT TR LN GR}
 set PROCTYPES {GMWPoint GMRoute GMTrack GMLine GMGroup}
 set MAPTYPES {WP RT TR}
@@ -39,14 +33,18 @@ set MAX(WP) $MAXWPOINTS
 set MAX(RT) $MAXROUTES
 set MAX(TR) $MAXTPOINTS
 
+# GR must be the last element of $RECTYPES list
+
 switch $MYGPS {
     Garmin {
-	set RECTYPES {WP RT TR GR}
+	# RECTYPES may be changed by proc RecAdjustToProtocols (garmin.tcl)
+	if { $SUPPORTLAPS } {
+	    set RECTYPES {WP RT TR LAP GR}
+	} else { set RECTYPES {WP RT TR GR} }
 	# character set for names
 	set RECNAMECHARS(Garmin) {^[-A-Z0-9]*$}
 	set RECNAMECHARS(Garmin,mess) "A..Z, 0..9, \"-\""
 	set UNDEFDATESECS [DateToSecs 1989 12 31 1 0 0]
-	set RECPROTOCOLS {garmin nmea stext simul drivesim}
     }
     Lowrance {
 	set RECTYPES {WP IC RT TR GR}
@@ -57,7 +55,6 @@ switch $MYGPS {
 	set MAX(IC) 100
 	set MAXICG 100
 	set UNDEFDATESECS 0
-	set RECPROTOCOLS {lowrance nmea}
     }
     Magellan {
 	# MGM contribution
@@ -66,7 +63,6 @@ switch $MYGPS {
 	set RECNAMECHARS(Magellan) {.*}
 	set RECNAMECHARS(Magellan,mess) $TXT(any)
 	set UNDEFDATESECS 0
-	set RECPROTOCOLS {magellan}
     }
 }
 
