@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: recmodels.tcl
-#  Last change:  30 April 2003
+#  Last change:  3 October 2004
 #
 # Includes contributions by
 #  - Brian Baulch (baulchb@onthenet.com.au) marked "BSB contribution"
@@ -25,12 +25,25 @@
 #  - Miguel Filgueiras (to code by others) marked "MF contribution"
 #
 
+  # assuming trade mark is the first list element in $GPSREC
+set MYGPS [lindex $GPSREC 0]
+set MYGPSMODEL [lreplace $GPSREC 0 0]
+
 # lists of known receivers models
 
  # Garmin and Lowrance and Magellan: no need for model name
-set RECMODELS(Garmin) {}
-set RECMODELS(Lowrance) {}
-set RECMODELS(Magellan) {}
+array set RECMODELS {
+    Garmin {}
+    Lowrance {}
+    Magellan {}
+}
+
+ # protocols supported for each trade mark
+array set RECPROTOCOLS {
+    Garmin   {garmin nmea stext simul drivesim}
+    Lowrance {lowrance nmea}
+    Magellan {magellan}
+}
 
 #####
 # related procs
@@ -42,10 +55,10 @@ proc FillRecModelsMenu {menu commd} {
     #   whose arguments will be the receiver name and $menu (even on sub-menus)
     # a selection will also have a callback to change the description of
     #  the options related to the receiver configuration
-    global RECMODELS MAXMENUITEMS TXT
+    global RECMODELS MAXMENUITEMS TXT GPSREC
 
     foreach tm [lsort -dictionary [array names RECMODELS]] {
-	if { "$RECMODELS($tm)" != "" } {
+	if { $RECMODELS($tm) != "" } {
 	    $menu add cascade -label $tm -menu $menu.m
 	    set mw $menu.m ; menu $mw -tearoff 0
 	    set n 0 ; set m 0
@@ -73,20 +86,27 @@ proc RecModelChange {tm} {
     #  configuration
     #  $tm is the receivers trade-mark in {Garmin, Lowrance, Magellan}
     global GPSREC OPTTYPE OPTGRPL OPTMENUPROC OPTMENUNAMES OPTMENUPREFIX \
-	    OPTMENUCONTS DISPOPTS
+	    OPTMENUCONTS DISPOPTS RECPROTOCOLS
 
     set OPTTYPE(_GPSRecConf) group
     switch $tm {
 	Garmin {
-	    set OPTGRPL(_GPSRecConf) {ACCEPTALLCHARS NAMELENGTH COMMENTLENGTH
-	              MAXWPOINTS MAXROUTES MAXWPINROUTE MAXTPOINTS CREATIONDATE
-	              NOLOWERCASE DEFAULTSYMBOL DEFAULTDISPOPT}
+	    set OPTGRPL(_GPSRecConf) {DEFTRECPROTOCOL ACCEPTALLCHARS
+		      NAMELENGTH COMMENTLENGTH
+	              MAXWPOINTS MAXROUTES MAXWPINROUTE AutoNumRts MAXTPOINTS
+		      CREATIONDATE NOLOWERCASE DEFAULTSYMBOL DEFAULTDISPOPT
+	              SUPPORTLAPS}
+            set OPTTYPE(DEFTRECPROTOCOL) fixedtextmenu
+            set OPTMENUCONTS(DEFTRECPROTOCOL) $RECPROTOCOLS(Garmin)
+            set OPTMENUNAMES(DEFTRECPROTOCOL) TXT
+            set OPTMENUPREFIX(DEFTRECPROTOCOL) {}
 	    set OPTTYPE(ACCEPTALLCHARS) boolean
             set OPTTYPE(NAMELENGTH) nat
             set OPTTYPE(COMMENTLENGTH) nat
             set OPTTYPE(MAXWPOINTS) nat
             set OPTTYPE(MAXROUTES) nat
             set OPTTYPE(MAXWPINROUTE) nat
+	    set OPTTYPE(AutoNumRts) boolean
             set OPTTYPE(MAXTPOINTS) nat
             set OPTTYPE(CREATIONDATE) boolean
             set OPTTYPE(NOLOWERCASE) boolean
@@ -98,6 +118,7 @@ proc RecModelChange {tm} {
             set OPTMENUCONTS(DEFAULTDISPOPT) $DISPOPTS
             set OPTMENUNAMES(DEFAULTDISPOPT) TXT
             set OPTMENUPREFIX(DEFAULTDISPOPT) DISP
+	    set OPTTYPE(SUPPORTLAPS) boolean
         }
         Lowrance {
 	    # BSB contribution
@@ -151,3 +172,7 @@ proc RecModelChange {tm} {
     }
     return
 }
+
+## set the options that depend on the receiver
+
+RecModelChange $MYGPS
