@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: search.tcl
-#  Last change:  18 January 2004
+#  Last change:  21 October 2004
 #
 
 proc Search {} {
@@ -26,8 +26,11 @@ proc Search {} {
 	SearchWPName SearchWPSymbol SearchRTWP SearchDate SearchSpec \
 	SearchDomain DEFAULTSYMBOL DPOSX DPOSY COLOUR TXT MESS TYPES \
 	ICONWIDTH ICONHEIGHT SYMBOLIMAGE NAMEWIDTH YEAR0 MONTHNAMES \
-	MAXMENUITEMS
+	MAXMENUITEMS SUPPORTLAPS
 
+    set stypes $TYPES
+    if { $SUPPORTLAPS } { lappend stypes LAP }
+    set SearchSpec(_types) $stypes
     # absolute paths for this window used elsewhere
     set w .gmsearch
     if { [winfo exists $w] } { Raise $w ; bell ; return }
@@ -48,7 +51,9 @@ proc Search {} {
     frame $w.fr.wh -relief flat -borderwidth 0
     label $w.fr.wh.tit -text $TXT(what):
     set pre $w.fr.wh.tit
-    foreach wh $TYPES {
+    # this will make easy some tests even if laps are not supported
+    set SearchSpec(LAP) 0
+    foreach wh $stypes {
 	set SearchSpec($wh) 0
 	checkbutton $w.fr.wh.b$wh -text $TXT(name$wh) -anchor w \
 		-variable SearchSpec($wh) -onvalue 1 -offvalue 0 \
@@ -182,11 +187,9 @@ proc Search {} {
 	    -menu $w.fr.fRT.wp.m
     FillItemsMenu $w.fr.fRT.wp.m wp WP SearchRTWP
 
-    frame $w.fr.fTR -relief flat -borderwidth 0
-    set SearchSpec(date) 0
-    checkbutton $w.fr.fTR.b -text "$TXT(nameTR) $TXT(started)" -anchor w \
-	    -variable SearchSpec(date) -onvalue 1 -offvalue 0 \
-	    -selectcolor $COLOUR(check) -state disabled
+    if { $SUPPORTLAPS } {
+	set trlaps "TR LAP"
+    } else { set trlaps TR }
     for { set ds "" ; set d 1 } { $d < 32 } { incr d } {
 	lappend ds $d
     }
@@ -194,30 +197,38 @@ proc Search {} {
     for { set ys "" ; set y $YEAR0 } { $y <= $cy } { incr y } {
 	lappend ys $y
     }
-    foreach de "d m y" vs [list $ds $MONTHNAMES $ys] {
-	set SearchDate($de) ""
-	menubutton $w.fr.fTR.$de -textvariable SearchDate($de) \
+    foreach wh $trlaps {
+	set f $w.fr.f$wh
+	frame $f -relief flat -borderwidth 0
+	set SearchSpec(date) 0
+	checkbutton $f.b -text "$TXT(name$wh) $TXT(started)" -anchor w \
+	    -variable SearchSpec($wh,date) -onvalue 1 -offvalue 0 \
+	    -selectcolor $COLOUR(check) -state disabled
+	foreach de "d m y" vs [list $ds $MONTHNAMES $ys] {
+	    set SearchDate($wh,$de) ""
+	    menubutton $f.$de -textvariable SearchDate($wh,$de) \
 		-relief raised -direction below -width $NAMEWIDTH \
-		-menu $w.fr.fTR.$de.m
-	menu $w.fr.fTR.$de.m -tearoff 0
-	set mw $w.fr.fTR.$de.m
-	$w.fr.fTR.$de.m add command -label "($TXT(any))" \
-		-command "set SearchDate($de) {}"
-	set n 1 ; set m 0
-	foreach v $vs {
-	    if { $n > $MAXMENUITEMS } {
-		$mw add cascade -label "$TXT(more) ..." -menu $mw.m$m
-		set mw $mw.m$m ; menu $mw -tearoff 0
-		set n 0 ; incr m
+		-menu $f.$de.m
+	    menu $f.$de.m -tearoff 0
+	    set mw $f.$de.m
+	    $f.$de.m add command -label "($TXT(any))" \
+		-command "set SearchDate($wh,$de) {}"
+	    set n 1 ; set m 0
+	    foreach v $vs {
+		if { $n > $MAXMENUITEMS } {
+		    $mw add cascade -label "$TXT(more) ..." -menu $mw.m$m
+		    set mw $mw.m$m ; menu $mw -tearoff 0
+		    set n 0 ; incr m
+		}
+		$mw add command -label $v -command "set SearchDate($wh,$de) $v"
+		incr n
 	    }
-	    $mw add command -label $v -command "set SearchDate($de) $v"
-	    incr n
 	}
+	set SearchWidgets($wh) $w.fr.f$wh.b
     }
-
     set SearchWidgets(WP) "$w.fr.fWP.b TR/$w.fr.fWPTR.its.tit"
     set SearchWidgets(RT) "$w.fr.fRT.b"
-    set SearchWidgets(TR) "$w.fr.fTR.b WP/$w.fr.fWPTR.its.tit"
+    lappend SearchWidgets(TR) WP/$w.fr.fWPTR.its.tit
     set SearchWidgets(LN) ""
     set SearchWidgets(GR) ""
 
@@ -252,11 +263,14 @@ proc Search {} {
 
     pack $w.fr.fRT.b $w.fr.fRT.wp -side left -padx 2
 
-    pack $w.fr.fTR.b $w.fr.fTR.d $w.fr.fTR.m $w.fr.fTR.y -side left -padx 2
-
-    pack $w.fr.frbt.ok $w.fr.frbt.cnc -side left -padx 5
     pack $w.fr.tit $w.fr.wh $w.fr.dom $w.fr.strs -side top -pady 5
-    pack $w.fr.fWPTR $w.fr.fWP $w.fr.fRT $w.fr.fTR -side top -pady 5 -anchor w
+    pack $w.fr.fWPTR $w.fr.fWP $w.fr.fRT -side top -pady 5 -anchor w
+    foreach wh $trlaps {
+	set f $w.fr.f$wh
+	pack $f.b $f.d $f.m $f.y -side left -padx 2
+	pack $f -side top -pady 5 -anchor w
+    }
+    pack $w.fr.frbt.ok $w.fr.frbt.cnc -side left -padx 5
     pack $w.fr.frbt -side top -pady 5
     pack $w.fr
 
@@ -269,17 +283,17 @@ proc Search {} {
 
 proc DoSearch {w} {
     # begin search
-    global TYPES SearchSpec SearchPattern SearchDistance SDatum SearchWPName \
+    global SearchSpec SearchPattern SearchDistance SDatum SearchWPName \
 	SearchRTWP WPDatum WPPosn AzimuthDegrees DSCALE MESS INVTXT
 
-    set whs ""
-    foreach wh $TYPES {
-	if { $SearchSpec($wh) } { lappend whs $wh }
-    }
-    if { $whs == "" } {
+    if { [set stypes $SearchSpec(_types)] == "" } {
 	GMMessage $MESS(mustchoose1type)
 	return
     }
+    set whs ""
+    foreach wh $stypes {
+	if { $SearchSpec($wh) } { lappend whs $wh }
+    }
     foreach s "name cmmt rmrk" {
 	if { $SearchSpec($s) } {
 	    set SearchPattern($s) [$w.fr.strs.f$s.e get]
@@ -299,7 +313,7 @@ proc DoSearch {w} {
 	    }
 	    fromPos {
 		set z $w.fr.fWPTR.dist.wpp.p.p.frp
-		set p [PosnGetCheck $z $SDatum GMMessage nil]
+		set p [PosnGetCheck $z.frp1 $SDatum GMMessage nil]
 		if { $p == "nil" } { return }
 		set SearchDistance(pos) $p
 		set SearchDistance(pformt) $INVTXT([$z.pfmt cget -text])
@@ -406,12 +420,20 @@ proc SearchDescription {} {
 	set f ";\n"
     }
     set dtrdt ""
-    if { $SearchSpec(date) } {
-	set dtrdt "${f}$TXT(date) $SearchDate(d) $SearchDate(m) $SearchDate(y)"
+    if { $SearchSpec(TR,date) } {
+	set dtrdt \
+	 "${f}$TXT(date) $SearchDate(TR,d) $SearchDate(TR,m) $SearchDate(TR,y)"
+	set f ";\n"
+    }
+    set dlapdt ""
+    if { $SearchSpec(LAP,date) } {
+	set dlapdt \
+      "${f}$TXT(date) $SearchDate(LAP,d) $SearchDate(LAP,m) $SearchDate(LAP,y)"
 	set f ";\n"
     }
     if { $f != "" } { set f "\n" }
-    return "${ddom}\n${dstrs}${fstrs}${ddist}${dsymb}${drtwp}${dtrdt}.$f"
+    return \
+	"${ddom}\n${dstrs}${fstrs}${ddist}${dsymb}${drtwp}${dtrdt}${dlapdt}.$f"
 }
 
 proc SearchFor {whs} {
@@ -463,14 +485,14 @@ proc SearchForAny {ids ixs wh} {
     #   $SearchSpec(symbol) boolean, $SearchWPSymbol
     #  for RT:
     #   $SearchSpec(RTWP) boolean, $SearchRTWP
-    #  for TR:
-    #   $SearchSpec(date) boolean
-    #     $SearchDate(d) day of month (range not checked) or ""
-    #     $SearchDate(m) month name or ""
-    #     $SearchDate(y) year or ""
+    #  for TR, LAP:
+    #   $SearchSpec($wh,date) boolean
+    #     $SearchDate($wh,d) day of month (range not checked) or ""
+    #     $SearchDate($wh,m) month name or ""
+    #     $SearchDate($wh,y) year or ""
     # return list of names
     global SearchSpec SearchPattern SDatum SearchWPSymbol SearchRTWP \
-	    SearchDate WPPosn WPDatum RTWPoints TRTPoints TRDatum
+	    SearchDate WPPosn WPDatum RTWPoints TRTPoints TRDatum LAPStart
 
     if { $ixs == "" } { return "" }
     foreach s "name rmrk" a "$ids ${wh}Obs" {
@@ -518,10 +540,10 @@ proc SearchForAny {ids ixs wh} {
 	    }
 	}
 	TR {
-	    if { $SearchSpec(date) } {
+	    if { $SearchSpec(TR,date) } {
 		set s 3
 		foreach a "d m y" {
-		    if { [set $a $SearchDate($a)] == "" } {
+		    if { [set $a $SearchDate(TR,$a)] == "" } {
 			set $a *
 			incr s -1
 		    }
@@ -552,6 +574,27 @@ proc SearchForAny {ids ixs wh} {
 		set ixs $nixs
 	    }
 	}
+	LAP {
+	    if { $SearchSpec(LAP,date) } {
+		set s 3
+		foreach a "d m y" {
+		    if { [set $a $SearchDate(LAP,$a)] == "" } {
+			set $a *
+			incr s -1
+		    }
+		}
+		if { $s > 0 } {
+		    set nixs ""
+		    foreach ix $ixs {
+			set secs [lindex $LAPStart($ix) 1]
+			if { [CompatibleDates $y $m $d $secs] } {
+			    lappend nixs $ix
+			}
+		    }
+		    set ixs $nixs
+		}
+	    }
+	}
     }
     return [lsort [Apply $ixs NameOf $wh]]
 }
@@ -563,8 +606,7 @@ proc SearchDistConstr {pos datum} {
     global SearchDistance SDatum
 
     if  { $SDatum != $datum } {
-	set pos [ConvertDatum [lindex $pos 0] [lindex $pos 1] \
-		$datum $SDatum DDD]
+	set pos [ToDatum [lindex $pos 0] [lindex $pos 1] $datum $SDatum]
     }
     set db [ComputeDistBearFD $SearchDistance(pos) $pos]
     set d [lindex $db 0]
@@ -593,17 +635,11 @@ proc SearchResults {lp} {
     # present search results described by list of pairs: type, names
     # this is currently done by creating and opening a group
     # return 0 if a new search is asked for by the user
-    global TXT MESS EdWindow
+    global TXT MESS EdWindow GRName
 
-    set grname [format "$TXT(srchres) %d" 0] ; set n 0
-    while { [IndexNamed GR $grname] != -1 } {
-	incr n ; set grname [format "$TXT(srchres) %d" $n]
-    }
-    set data [FormData GR "Name Obs Conts" \
-	         [list $grname [SearchDescription] $lp]]
-    set ix [CreateItem GR $data]
+    set ix [CreateGRFor srchres [SearchDescription] $lp]
     set w [OpenItem GR $ix]
-    switch [GMSelect "$MESS(resultsin) $grname" \
+    switch [GMSelect "$MESS(resultsin) $GRName($ix)" \
 	    [list Ok $TXT(another) $TXT(change) $TXT(cancel)] \
 	    "ok another change cancel"] {
 	ok {
@@ -654,7 +690,7 @@ proc SearchToggleDomain {} {
 
 proc SearchToggle {wh} {
     # enable/disable checkbuttons in search window that are specific to
-    #  search of $wh (in $TYPES) items
+    #  search of $wh (in $TYPES or LAP) items
     global SearchSpec SearchWidgets
 
     if { $SearchSpec($wh) } {
@@ -666,14 +702,12 @@ proc SearchToggle {wh} {
 		set l [split $w /]
 		set wh2 [lindex $l 0] ; set w [lindex $l 1]
 		if { $SearchSpec($wh) == $SearchSpec($wh2) } {
-		    if {! $SearchSpec($wh) } { $w deselect }
+		    if { ! $SearchSpec($wh) } { $w deselect }
 		    $w configure -state $st
-		} else {
-		    $w configure -state normal
-		}
+		} else { $w configure -state normal }
 	    }
 	    * {
-		if {! $SearchSpec($wh) } { $w deselect }
+		if { ! $SearchSpec($wh) } { $w deselect }
 		$w configure -state $st
 	    }
 	}
