@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: serial.tcl
-#  Last change:  11 July 2004
+#  Last change:  9 November 2004
 #
 # Includes contributions by Matt Martin (matt.martin@ieee.org)
 #  marked "MGM contribution"
@@ -233,9 +233,14 @@ proc EndOutProt {pid} {
 proc BadFloats {} {
     # check whether conversions of bytes to float are working correctly
     #  in this machine
-    global MESS
+    global MESS tcl_platform
 
-    if { abs([UnPackData "A B C D" float]-781.035217285) > 1e-3 } {
+    if { $tcl_platform(byteOrder) == "littleEndian" } {
+	binary scan [join "A B C D" ""] "f" x
+    } else {
+	binary scan [join "D C B A" ""] "f" x
+    }
+    if { abs($x-781.035217285) > 1e-3 } {
 	return [expr ! [GMConfirm $MESS(badfloats)]]
     }
     return 0
