@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: trtort.tcl
-#  Last change:  17 September 2004
+#  Last change:  25 November 2004
 #
 # Includes contributions by Brian Baulch (baulchb@onthenet.com.au)
 #  marked "BSB contribution"
@@ -153,12 +153,13 @@ proc TRCvCommitRT {w} {
 	    incr n ; set id [format "ZT%04d" $n]
 	}
 	incr n
-	foreach "p pfmt pfdatum" \
-	    [FormatPosition $latd $longd $datum $PositionFormat "" DDD] {
+	foreach "posn pfmt pfdatum" \
+	    [FormatPosition [lindex $p 0] [lindex $p 1] $datum \
+		 $PositionFormat "" DDD] {
 		break
 	}
 	set data [FormData WP "Name PFrmt Posn Datum Date Alt" \
-		     [list $id $pfmt $p $pfdatum $date [lindex $p 6]]]
+		     [list $id $pfmt $posn $pfdatum $date [lindex $p 6]]]
 	set ix [CreateItem WP $data]
 	lappend wps $id
     }
