@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: util.tcl
-#  Last change:  18 January 2004
+#  Last change:  7 October 2004
 #
 # Includes contributions by Brian Baulch (baulchb@onthenet.com.au)
 #  marked "BSB contribution"
@@ -137,45 +137,77 @@ proc FillPFormtMenu {menu comm args} {
 
 ### positions
 
-proc FillPos {w pformt posn state chgvar} {
-    # create widgets to display position
-    #  $w is path to parent window
+proc FillPos {w pformt posns state chgvorp} {
+    # create widgets to display positions
+    #  $w is path to either an empty frame where a single position in
+    #     lists $posns is to be displayed, or to frame that will contain
+    #     frames with widgets for each position in $posns
     #  $pformt is the position format (see array POSTYPE, projections.tcl)
-    #  $posn is the position (see proc CreatePos, compute.tcl)
+    #  $posns is a list of positions (see proc FormatPosition, compute.tcl)
     #  $state in {normal, disabled}
-    #  $chgvar is either "nil" or name of global variable to set to
-    #     1 if the user types or pastes in any entry
+    #  $chgvorp is either "nil" or:
+    #     - if there is a single position, the name of global variable to
+    #     set to 1 if the user types in any entry and that contains the
+    #     current position otherwise; see procs ChangePFormt and
+    #     PosnGetCheckEmpty
+    #     - else, "=PREFIX" describing global variables used in the same
+    #     way for each position; each name has the prefix followed by the
+    #     number from 1 of the position
+    # the widgets for each position are created under frames $w.frp$i where $i
+    #  is the order from 1
+    # the frames $w.frp1, $w.frp2, ... are created and packed from top if
+    #  they do not exist
     global TXT POSTYPE
 
-    pack $w.pfmt -side left -padx 3
-    set ep [lrange $posn 2 end]
     switch $POSTYPE($pformt) {
 	latlong {
 	    set ns [list $TXT(lat) $TXT(long)]
-	    FillEntries $w "lat long" $ns "12 12" $ep $state $chgvar
+	    set fs "lat long" ; set ws "12 12"
 	}
 	utm {
 	    set ns [list $TXT(ze) $TXT(zn) $TXT(eastng) $TXT(nrthng)]
-	    FillEntries $w "ze zn eng nng" $ns "3 3 8 8" $ep $state $chgvar
+	    set fs "ze zn eng nng" ; set ws "3 3 8 8"
 	}
 	grid {
 	    set ns [list $TXT(zone) $TXT(eastng) $TXT(nrthng)]
-	    FillEntries $w "zn eng nng" $ns "5 8 8" $ep $state $chgvar
+	    set fs "zn eng nng" ; set ws "5 8 8"
 	}
 	nzgrid {
 	    set ns [list $TXT(eastng) $TXT(nrthng)]
-	    FillEntries $w "eng nng" $ns "8 8" $ep $state $chgvar
+	    set fs "eng nng" ; set ws "8 8"
 	}
 	mh {
-	    FillEntries $w mh "" 8 $ep $state $chgvar
+	    set ns "" ; set fs  mh ; set ws 8
 	}
     }
+    if { [winfo children $w] == "" } {
+	# single position, repopulate $w
+	FillEntries $w $fs $ns $ws [lrange [lindex $posns 0] 2 end] $state \
+	    $chgvorp
+	return
+    }
+    set n 1
+    if { [regsub {^=} $chgvorp "" prefix] } {
+	set nvar 1
+    } else { set nvar 0 ; set chgvar $chgvorp }
+    foreach posn $posns {
+	set wf $w.frp$n
+	if { ! [winfo exists $wf] } {
+	    frame $wf
+	    pack $wf -side top
+	}	    
+	set ep [lrange $posn 2 end]
+	if { $nvar } { set chgvar ${prefix}$n }
+	FillEntries $wf $fs $ns $ws $ep $state $chgvar
+	incr n
+    }
     return
 }
 
 proc PosnGetCheck {w datum errproc chgvar} {
     # get and check position in edit/show window
-    #  $w is path to parent window
+    #  $w is path to parent window of position widgets, whose parent
+    #     contains the widget for the position format
     #  $errproc is procedure to call on error
     #  $chgvar is either "nil" or name of global variable to set to
     #     1 if the user types in any entry and that contains the
@@ -193,13 +225,14 @@ proc PosnGetCheck {w datum errproc chgvar} {
 
 proc PosnGetCheckEmpty {w datum errproc chgvar} {
     # get and check position in edit/show window
-    #  $w is path to parent window
+    #  $w is path to parent window of position widgets, whose parent
+    #     contains the widget for the position format
     #  $errproc is procedure to call on error
     #  $chgvar is either "nil" or name of global variable to set to
     #     1 if the user types in any entry and that contains
     #     the current position otherwise (possibly "")
     # returns "empty" if there are empty fields, and "nil" on error
-    global MESS TXT INVTXT POSTYPE
+    global MESS INVTXT POSTYPE
 
     if { $chgvar != "nil" } {
 	global $chgvar
@@ -207,7 +240,8 @@ proc PosnGetCheckEmpty {w datum errproc chgvar} {
 	if { [set p [set $chgvar]] == "" } { return empty }
 	if { $p != 1 } { return $p }
     }
-    set pf $INVTXT([$w.pfmt cget -text])
+    set wp [winfo parent $w]
+    set pf $INVTXT([$wp.pfmt cget -text])
     switch [set ptype $POSTYPE($pf)] {
 	latlong {
 	    set wlat [$w.lat get] ; set wlong [$w.long get]
@@ -249,13 +283,11 @@ proc PosnGetCheckEmpty {w datum errproc chgvar} {
 		    return nil
 		}
 	    } else { set gr 0 ; set zn "" }
+	    if { [BadDatumFor $pf $datum GMMessage] != 0 } { return nil }
 	    set p [GridToDegrees $pf $zn $eng $nng $datum]
 	    if { $p == 0 } {
 		$errproc $MESS(outofgrid)
 		return nil
-	    } elseif { $p == -1 } {
-		$errproc [format $MESS(badgriddatum) $TXT($pf) [GridDatum $pf]]
-		return nil
 	    }
 	    if { $gr } {
 		lappend p $zn $eng $nng
@@ -278,13 +310,14 @@ proc PosnGetCheckEmpty {w datum errproc chgvar} {
 
 proc RevertPos {w pformt ptype posn} {
     # change position values keeping its format
-    #  $w is path to parent window
+    #  $w is path to parent window of position widgets, whose parent
+    #     contains the widget for the position format
     #  $pformt is position format (see projections.tcl)
     #  $ptype is type of position format (see array POSTYPE, projections.tcl)
-    #  $posn is the position (see proc CreatePos, compute.tcl)
+    #  $posn is the position (see proc FormatPosition, compute.tcl)
     global TXT
 
-    $w.pfmt configure -text $TXT($pformt)
+    [winfo parent $w].pfmt configure -text $TXT($pformt)
     switch $ptype {
 	latlong {
 	    set bs {lat long} ; set is {2 3}
@@ -302,113 +335,131 @@ proc RevertPos {w pformt ptype posn} {
 	    set bs mh ; set is 2
 	}
     }
+    set st [$w.[lindex $bs 0] cget -state]
     foreach b $bs k $is {
+	$w.$b configure -state normal
 	$w.$b delete 0 end
 	$w.$b insert 0 [lindex $posn $k]
+	$w.$b configure -state $st
     }
     return
 }
 
-proc RedrawPos {w oldtype pformt posn chgvar} {
+proc RedrawPos {w pformt posn chgvar st} {
     # display position under a new format
-    #  $w is path to parent window
-    #  $oldtype is type of old format (see array POSTYPE, projections.tcl)
+    #  $w is path to parent window of position widgets, whose parent
+    #     contains the widget for the position format
     #  $pformt is the new format (see projections.tcl)
-    #  $posn is the position (see proc CreatePos, compute.tcl)
+    #  $posn is the position (see proc FormatPosition, compute.tcl)
     #  $chgvar is either "nil" or name of global variable to set to
     #     1 if the user types in any entry and that contains the
     #     current position otherwise (possibly "")
+    #  $st is state for position widgets
     global TXT
 
-    switch $oldtype {
-	latlong { DestroyAll $w "lattitle lat longtitle long" }
-	utm { DestroyAll $w "zetitle ze zntitle zn engtitle eng nngtitle nng" }
-	grid { DestroyAll $w "zntitle zn engtitle eng nngtitle nng" }
-	nzgrid { DestroyAll $w "zn engtitle eng nngtitle nng" }
-	mh { DestroyAll $w "mhtitle mh" }
-    }
-    $w.pfmt configure -text $TXT($pformt)
-    FillPos $w $pformt $posn normal $chgvar
+    foreach s [winfo children $w] { destroy $s }
+    FillPos $w $pformt [list $posn] $st $chgvar
     return
 }
 
-proc ChangePFormt {pformt dvar dvref w chgvar} {
-    # change format of position in window
-    #  $w is path to parent window
+proc ChangePFormt {pformt dvar dvref w chgvorp st} {
+    # change format of positions in window
+    #  $w is path to parent window containing frp$i sub-frames for
+    #     each position with $i an integer from 1
     #  $pformt is position format (see array POSTYPE, projections.tcl)
-    #  $chgvar is either "nil" or name of global variable to set to
-    #     1 if the user types in any entry and that contains the
-    #     current position otherwise (possibly "")
-    #  $dvar is name of global variable or array
-    #  $dvref is name of variable or array(element)
-    global INVTXT $dvar MESS POSTYPE
+    #  $chgvorp is either "nil" or:
+    #     - if there is a single position, the name of global variable to
+    #     set to 1 if the user types in any entry and that contains the
+    #     current position otherwise; see procs ChangePFormt and
+    #     PosnGetCheckEmpty
+    #     - else, "=PREFIX" describing global variables used in the same
+    #     way for each position; each name has the prefix followed by the
+    #     number from 1 of the position
+    #  $dvar is name of global variable or array for datum
+    #  $dvref is name of variable or array(element) for datum
+    #  $st is state of the position widgets
+    global INVTXT $dvar MESS POSTYPE TXT
 
     set opf $INVTXT([$w.pfmt cget -text])
     if { $opf == $pformt } { return }
+    set datum [set $dvref]
+    if { [set ndatum [BadDatumFor $pformt $datum Ignore]] == 0 } {
+	set ndatum $datum
+    }
+    if { [regsub {^=} $chgvorp "" prefix] } {
+	set nvar 1
+    } else { set nvar 0 ; set chgvar $chgvorp }
+    set frs "" ; set posns ""
+    foreach fr [winfo children $w] {
+	if { [regexp {\.frp([0-9]+)$} $fr x n] } {
+	    lappend frs $fr
+	    if { $nvar } { set chgvar ${prefix}$n }
+	    set p [PosnGetCheckEmpty $fr $datum GMMessage $chgvar]
+	    if { $p == "nil" } { return }
+	    if { $p == "empty" } {
+		set p ""
+	    } else {
+		set p [lindex \
+			   [FormatPosition [lindex $p 0] [lindex $p 1] $datum \
+				$pformt ""] 0]
+		if { [lindex $p 2] == "--" } {
+		    GMMessage $MESS(outofgrid)
+		    return
+		}
+	    }
+	    lappend posns $p
+	}
+    }
     set ot $POSTYPE($opf) ; set nt $POSTYPE($pformt)
-    set op [PosnGetCheckEmpty $w [set $dvref] GMMessage $chgvar]
-    if { $op == "nil" } { return }
-    if { $nt == "grid" || $nt == "nzgrid" } {
-	set gr 1
-    } else { set gr 0 }
-    if { $op == "empty" } {
-	set np ""
-	if { $gr && [set gdatum [GridDatum $pformt]] != "" && \
-		 [set $dvref] != $gdatum } {
-	    set $dvref $gdatum
-	}
-    } else {
-	set datum [set $dvref] ; set chgdatum 0
-	if { $gr && [set gdatum [GridDatum $pformt]] != "" && \
-		$datum != $gdatum } {
-	    set np [ConvertDatum [lindex $op 0] [lindex $op 1] \
-		                 $datum $gdatum $pformt]
-	    set datum $gdatum
-	    set chgdatum 1
-	} else {
-	    set np [CreatePos [lindex $op 0] [lindex $op 1] $pformt $datum]
-	}
-	if { $gr && [lindex $np 2] == "--" } {
-	    GMMessage $MESS(outofgrid)
-	    return
-	}
-	if { $chgdatum } { set $dvref $datum }
-    }
-    if { $chgvar != "nil" } {
-	global $chgvar
+    foreach fr $frs np $posns {
+	if { $chgvorp != "nil" } {
+	    if { $nvar } { set chgvar ${prefix}$n }
+	    global $chgvar
 
-	set $chgvar $np
-    }
-    if { $ot == $nt } {
-	RevertPos $w $pformt $nt $np
-    } else {
-	RedrawPos $w $ot $pformt $np $chgvar
+	    set $chgvar $np
+	}
+	if { $ot == $nt } {
+	    RevertPos $fr $pformt $nt $np
+	} else {
+	    RedrawPos $fr $pformt $np $chgvar $st
+	}
     }
+    set $dvref $ndatum
+    $w.pfmt configure -text $TXT($pformt)
     return
 }
 
-proc ChangeDatum {datum dvar dvref chgvar posfr} {
-    # change datum 
+proc ChangeDatum {datum dvar dvref chgvorp posfr st} {
+    # change datum
+    #   $posfr is path to parent window containing frp$i sub-frames for
+    #     each position with $i an integer from 1
+    # see proc ChangePFormt for the meaning of the other arguments
     global $dvar INVTXT MESS POSTYPE
 
     set olddatum [set $dvref]
     if { $olddatum == $datum } { return }
-    set op [PosnGetCheck $posfr $olddatum Ignore $chgvar]
     set pformt $INVTXT([$posfr.pfmt cget -text])
-    if { ([set pt $POSTYPE($pformt)] == "grid" || $pt == "nzgrid") && \
-	    [set gdatum [GridDatum $pformt]] != "" && \
-	    $datum != $gdatum } {
-	GMMessage [format $MESS(cantchggriddatum) $gdatum]
+    if { [BadDatumFor $pformt $datum GMMessage] != 0 } {
 	return
     }
-    if { $op != "nil" } {
-	set np [ConvertDatum [lindex $op 0] [lindex $op 1] \
-		             $olddatum $datum $pformt]
-	if { $chgvar != "nil" } {
-	    global $chgvar
-	    set $chgvar $np
+    if { [regsub {^=} $chgvorp "" prefix] } {
+	set nvar 1
+    } else { set nvar 0 ; set chgvar $chgvorp }
+    foreach fr [winfo children $posfr] {
+	if { [regexp {\.frp([0-9]+)$} $fr x n] } {
+	    if { $nvar } { set chgvar ${prefix}$n }
+	    set op [PosnGetCheck $fr $olddatum Ignore $chgvar]
+	    if { $op != "nil" } {
+		set np [lindex [FormatPosition [lindex $op 0] [lindex $op 1] \
+				    $olddatum $pformt $datum] 0]
+		RevertPos $fr $pformt $POSTYPE($pformt) $np
+		if { $chgvar != "nil" } {
+		    global $chgvar
+
+		    set $chgvar $np
+		}
+	    }
 	}
-	RevertPos $posfr $pformt $pt $np
     }
     set $dvref $datum
     return
@@ -447,13 +498,6 @@ proc DestroyRGrabs {w oldgrabs} {
     return
 }
 
-proc DestroyAll {w subws} {
-    # destroy all sub-windows in $subws of window $w
-
-    foreach s $subws { destroy $w.$s }
-    return
-}
-
 proc Raise {w} {
 
     raise $w ; focus $w
@@ -531,6 +575,40 @@ proc ToggleWindow {w x y} {
     return
 }
 
+## changing state of interface
+
+proc ChangeOnState {what st} {
+    # change state of some widgets according to specification in WConf array
+    #  $what is index in WConf array
+    #  $st in {normal, disabled}
+    # entries of WConf used here are lists of lists; information in each
+    #  sublist depends on its 1st element: 
+    #   menu - 2nd element is a list of pairs with menu path and list of
+    #          entries
+    #   button (or menubutton) - 2nd element is list of paths
+    global WConf CMDLINE
+
+    if { $CMDLINE } { return }
+    foreach p $WConf($what) {
+	switch [lindex $p 0] {
+	    menu {
+		foreach m [lindex $p 1] {
+		    set w [lindex $m 0]
+		    foreach e [lindex $m 1] {
+			$w entryconfigure $e -state $st
+		    }
+		}
+	    }
+	    button -  menubutton {
+		foreach b [lindex $p 1] {
+		    $b configure -state $st
+		}
+	    }
+	}
+    }
+    return
+}
+
 ## operations on entries
 
 proc CheckEntries {errproc errval descr} {
